package com.unis.hlht.cjlksj.server.controller.datashow;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson.JSONObject;
import com.hikvision.artemis.sdk.ArtemisHttpUtil;
import com.hikvision.artemis.sdk.config.ArtemisConfig;
import com.unis.hlht.cjlksj.server.mapper.TestMapper;
import com.unis.hlht.cjlksj.server.redisstream.StreamRedisQueue;
import com.unis.hlht.cjlksj.server.server.DataCurdServer;
import com.unis.hlht.cjlksj.server.server.haikang.HaikangServer;
import com.unis.hlht.cjlksj.server.utils.*;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.dom4j.DocumentException;
import org.dom4j.Element;
import org.dom4j.Node;
import org.dom4j.io.SAXReader;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.hlht.cjlksj.server.dto.upload.UploadDTO;
import com.unis.hlht.cjlksj.server.dto.upload.UploadQueryDTO;
import com.unis.hlht.cjlksj.server.entity.LiangKuApiEntity;
import com.unis.hlht.cjlksj.server.mapper.GrabResultMapper;
import com.unis.hlht.cjlksj.server.mapper.LiangKuApiMapper;
import com.unis.hlht.cjlksj.server.mapper.SysUploadErrorResultMapper;
import com.unis.hlht.cjlksj.server.server.DataUpLoadServer;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;

/**
 * 功能描述: 功能测试controller层
 *
 * @Auther: 蒋青茂
 * @Date: 2019-3-19 10:30
 */
@SuppressWarnings("all")
@Log4j2
@Controller
@Api(value = "功能测试", description = "功能测试控制层")
public class TestController {

    @Autowired
    private LiangKuApiMapper mapper;
    @Autowired
    private GrabResultMapper regexMapper;
    @Autowired
    private SysUploadErrorResultMapper sysUploadErrorResultMapper;


    /**
     * @粮库数据上传通道
     * @param：[dto] @rerurn：Result
     * @author：蒋青茂 @date2019-3-19
     */
    @ApiOperation("粮库数据上报通道测试能否访问")
    @PostMapping(value = "/testUrlConnect")
    @ResponseBody
    public String upload(@RequestBody UploadDTO dto) {
        List<LiangKuApiEntity> list = mapper.findAll();
        StringBuilder rsb = new StringBuilder();
        for (LiangKuApiEntity t : list) {
            try {
                String url = t.getUrl();
                int isConnect = testWsdlConnection(url);
                String isPing = url.substring(7, url.lastIndexOf(":"));
//				String result = "PING："+PingUtil.ping(isPing, 5, 5000) +
//						"服务调用："+isConnect + "->" + t.getName() + "--" + url;
                String result = "服务调用：" + isConnect + "->" + t.getName() + "--" + url;
                System.err.print(result);
                rsb.append(result + "\n");
            } catch (Exception e) {
            }
        }
        return rsb.toString();
    }


    @ApiOperation(value = "粮库上传数据错误信息PAGE", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "beginTime", value = "开始时间：格式yyyy-MM-dd HH:mm:ss", dataType = "string", paramType = "query"),
            @ApiImplicitParam(name = "orgNo", value = "上传数据组织机构代码：如36100001111", dataType = "string", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间：格式yyyy-MM-dd HH:mm:ss", dataType = "string", paramType = "query")})
    @GetMapping(value = "/cuowuxingxin")
    public String downUploadErrorInfoPage(HttpServletRequest request, HttpServletResponse response, Model m,
                                          @RequestParam(value = "beginTime", required = false) String beginTime,
                                          @RequestParam(value = "orgNo", required = false) String orgNo,
                                          @RequestParam(value = "endTime", required = false) String endTime) {
        StringBuffer sqlSb = new StringBuffer("select ORG_NO,ORG_NAME,ERR_INFO,CREATE_TIME from SYS_UPLOAD_ERROR_RESULT where 1=1");
        if (StringUtils.isNotEmpty(orgNo)) {
            sqlSb.append(" and ORG_NO = ").append("'" + orgNo + "'");
        }
        if (StringUtils.isNotEmpty(beginTime)) {
            sqlSb.append(" and CREATE_TIME >= TO_DATE('" + beginTime + "','yyyy-MM-dd HH24:mi:ss')");
        }
        if (StringUtils.isNotEmpty(endTime)) {
            sqlSb.append(" and CREATE_TIME <= TO_DATE('" + endTime + "','yyyy-MM-dd HH24:mi:ss')");
        }
        sqlSb.append(" ORDER BY CREATE_TIME DESC,ORG_NAME DESC");
        List<Map> mlist = sysUploadErrorResultMapper.select(sqlSb.toString());
        m.addAttribute("list", mlist);
        m.addAttribute("now", DateFormat.getDateTimeInstance().format(new Date()));
        m.addAttribute("ip", getIpAddr(request));
        return "cuowuxingxin";
    }

    @ApiOperation(value = "粮库上传数据错误信息PAGE", httpMethod = "POST")
    @PostMapping(value = "/searchUploadErrorInfoPage")
    @ResponseBody
    public PageInfo<Map> searchUploadErrorInfoPage(UploadQueryDTO dto) {
        Integer pageNo = dto.getPageNo() == null ? 1 : dto.getPageNo();
        Integer pageSize = dto.getPageSize() == null ? 10 : dto.getPageSize();

        Map map = new HashMap<>();
        StringBuffer sqlSb = new StringBuffer("select ORG_NO,ORG_NAME,ERR_INFO,CREATE_TIME from SYS_UPLOAD_ERROR_RESULT where 1=1");
        String orgNo = dto.getOrgNo();
        String beginTime = dto.getBeginTime();
        String endTime = dto.getEndTime();
        if (StringUtils.isNotEmpty(orgNo)) {
            sqlSb.append(" and ORG_NO = ").append("'" + orgNo + "'");
        }
        if (StringUtils.isNotEmpty(beginTime)) {
            sqlSb.append(" and CREATE_TIME >= TO_DATE('" + beginTime + "','yyyy-MM-dd HH24:mi:ss')");
        }
        if (StringUtils.isNotEmpty(endTime)) {
            sqlSb.append(" and CREATE_TIME <= TO_DATE('" + endTime + "','yyyy-MM-dd HH24:mi:ss')");
        }
        sqlSb.append(" ORDER BY CREATE_TIME DESC,ORG_NAME DESC");

        PageHelper.startPage(pageNo, pageSize);
        PageInfo<Map> pageInfo = new PageInfo<>(sysUploadErrorResultMapper.select(sqlSb.toString()));
        return pageInfo;
    }

	
/*	@ApiOperation(value = "深度校验", httpMethod = "GET")
	@RequestMapping(value = "/regexShengdu")
	public String regexShengdu(Model m, HttpServletRequest request) {
		m.addAttribute("now", DateFormat.getDateTimeInstance().format(new Date()));

		m.addAttribute("list", getData());
		m.addAttribute("ip", getIpAddr(request));
		return "hello";

	}*/

    @ApiOperation(value = "深度校验", httpMethod = "POST")
    @PostMapping(value = "/searchRegexData")
    @ResponseBody
    public Map searchRegexData(HttpServletRequest request) {
        Map map = new HashMap<>();
        map.put("now", DateFormat.getDateTimeInstance().format(new Date()));
        map.put("list", getData());
        map.put("ip", getIpAddr(request));
        return map;
    }

    @ApiOperation(value = "深度校验", httpMethod = "GET")
    @RequestMapping(value = "/shengdujiaoyan")
    public String shengdujiaoyan(Model m, HttpServletRequest request) {
        m.addAttribute("now", DateFormat.getDateTimeInstance().format(new Date()));
        m.addAttribute("list", getData());
        m.addAttribute("ip", getIpAddr(request));
        return "shengdujiaoyan";
    }


    @ApiOperation("下载粮库上传数据错误信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "beginTime", value = "开始时间：格式yyyy-MM-dd HH:mm:ss", dataType = "string", paramType = "query"),
            @ApiImplicitParam(name = "OrgNo", value = "上传数据组织机构代码：如36100001111", dataType = "string", paramType = "query"),
            @ApiImplicitParam(name = "EndTime", value = "结束时间：格式yyyy-MM-dd HH:mm:ss", dataType = "string", paramType = "query")})
    @GetMapping(value = "/downUploadErrorInfo")
    public void downUploadErrorInfo(HttpServletRequest request, HttpServletResponse response,
                                    @RequestParam(value = "beginTime", required = false) String beginTime,
                                    @RequestParam(value = "OrgNo", required = false) String OrgNo,
                                    @RequestParam(value = "EndTime", required = false) String EndTime) {
        StringBuffer sqlSb = new StringBuffer("select ORG_NO,ORG_NAME,ERR_INFO,CREATE_TIME from SYS_UPLOAD_ERROR_RESULT where 1=1");
        if (StringUtils.isNotEmpty(OrgNo)) {
            sqlSb.append(" and ORG_NO = ").append("'" + OrgNo + "'");
        }
        if (StringUtils.isNotEmpty(beginTime)) {
            sqlSb.append(" and CREATE_TIME >= TO_DATE('" + beginTime + "','yyyy-MM-dd HH24:mi:ss')");
        }
        if (StringUtils.isNotEmpty(EndTime)) {
            sqlSb.append(" and CREATE_TIME <= TO_DATE('" + EndTime + "','yyyy-MM-dd HH24:mi:ss')");
        }
        List<Map> mlist = sysUploadErrorResultMapper.select(sqlSb.toString());
        //excel文件名
        String fileName = DateUtil.getCurrentStringDate() + "粮库上传数据错误信息" + ".xls";
        //excel标题
        String[] title = {"库点上传组织编码", "库点上传组织名称", "错误信息", "上传时间"};
        //sheet名
        String[][] content = new String[mlist.size()][4];
        for (int i = 0; i < mlist.size(); i++) {
            Map obj = mlist.get(i);
            content[i][0] = obj.get("ORG_NO").toString();
            content[i][1] = obj.get("ORG_NAME").toString();
            content[i][2] = obj.get("ERR_INFO").toString();
            content[i][3] = obj.get("CREATE_TIME").toString();
        }
        //创建HSSFWorkbook
        HSSFWorkbook wb = ExcelUtil.getHSSFWorkbook("错误数据", title, content, null);
        //响应到客户端
        try {
            try {
                fileName = new String(fileName.getBytes("UTF-8"), "ISO-8859-1");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
            response.setContentType("application/octet-stream;charset=utf-8");
            response.setHeader("Content-Disposition", "attachment;filename=" + fileName);
            response.addHeader("Pargam", "no-cache");
            response.addHeader("Cache-Control", "no-cache");
            OutputStream outputStream = response.getOutputStream();
            wb.write(outputStream);
            outputStream.flush();
            outputStream.close();
        } catch (Exception e) {

        }
    }

    public List<Map> getData() {
        // 加载数据校验规则
        org.dom4j.Document document = getDom(
                DataUpLoadServer.class.getClassLoader().getResourceAsStream("config/shanxi_shengdu.xml"));
        Element root = document.getRootElement();
        List<Node> columnList = null;
        Element columnEle = null;
        String sql = null, columnname = null, value = null, regex = null, tableName = null, remark = null;

        List tableEles = root.selectNodes("/tables/table");
        List<Map> mlist = new ArrayList<>();
        if (tableEles != null) {
            for (int i = 0; i < tableEles.size(); i++) {
                List<String> infoList = new ArrayList<String>();
                StringBuffer sb = new StringBuffer();
                Element ele = (Element) tableEles.get(i);
                tableName = ele.attributeValue("name");
                sb.append("表名：").append(tableName);
                sb.append("\n");
                columnList = ele.selectNodes("column[@sql|@remark]");
                int columnSize = columnList != null ? columnList.size() : 0;
                if (columnSize > 0) {
                    for (int x = 0; x < columnSize; x++) {
                        columnEle = (Element) columnList.get(x);
                        columnname = columnEle.getTextTrim().toUpperCase();
                        sql = columnEle.attributeValue("sql");
                        List<Map> list = regexMapper.select(sql);
                        remark = columnEle.attributeValue("remark");
                        sb.append("\t");
                        sb.append("问题：" + columnname + remark);
                        sb.append("\n\t***********************相关数据****************************\n");
                        for (Map map : list) {
                            String info = map.get("QYXX") + "";
                            String errorColumn = map.get("ERRORCOLUMN") + "";
                            sb.append("\t\t");
                            sb.append(info);
                            sb.append("\n");
                            Map<String, String> vM = new HashMap<String, String>();
                            vM.put("TNAME", tableName);
                            vM.put("KDMC", info);
                            vM.put("INFO", "问题：" + remark);
                            vM.put("VAL", errorColumn);
                            vM.put("NAME", columnname);
                            if (mlist.contains(vM) == false) {
                                mlist.add(vM);
                            }
                        }
                    }
                }
                // CreateTable.writeTxt("E://" + DateUtil.getCurrentStringDate() +
                // "国家局反馈部分问题.txt", sb.toString());
            }
        }
        return mlist;
    }

    @ApiOperation("深度校验")
    @GetMapping(value = "/regexShengduExcel")
    public void regexShengduExcel(HttpServletRequest request, HttpServletResponse response) {
        List<Map> mlist = getData();
        //excel文件名
        String fileName = DateUtil.getCurrentStringDate() + "深度校验问题" + ".xls";
        //excel标题
        String[] title = {"表名", "库点", "错误信息", "字段名称", "字段值"};
        //sheet名
        String sheetName = "错误数据";
        String[][] content = new String[mlist.size()][5];
        for (int i = 0; i < mlist.size(); i++) {
            Map obj = mlist.get(i);
            content[i][0] = obj.get("TNAME").toString();
            content[i][1] = obj.get("KDMC").toString();
            content[i][2] = obj.get("INFO").toString();
            content[i][3] = obj.get("NAME").toString();
            content[i][4] = obj.get("VAL").toString();
        }
        //创建HSSFWorkbook
        HSSFWorkbook wb = ExcelUtil.getHSSFWorkbook(sheetName, title, content, null);
        //响应到客户端
        try {
            try {
                fileName = new String(fileName.getBytes("UTF-8"), "ISO-8859-1");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
            response.setContentType("application/octet-stream;charset=utf-8");
            response.setHeader("Content-Disposition", "attachment;filename=" + fileName);
            response.addHeader("Pargam", "no-cache");
            response.addHeader("Cache-Control", "no-cache");
            OutputStream outputStream = response.getOutputStream();
            wb.write(outputStream);
            outputStream.flush();
            outputStream.close();
        } catch (Exception e) {

        }
    }


    @ApiOperation("深度校验")
    @GetMapping(value = "/regexShengduExcelV2")
    public void regexShengduExcelTest(HttpServletRequest request, HttpServletResponse response) {
        List<Map> mlist = getData();
        List<Map> sheetMapList = new ArrayList<>();
        List<String> indexList = new ArrayList<>();


        for (Map map : mlist) {
            String kdmc = map.get("KDMC") + "";
            String tyshxydm = "";
            if (kdmc.contains("-")) {
                String[] split = kdmc.split("-");
                tyshxydm = split[1];
                if (split[0].equals("")) {
                    kdmc = split[1];
                } else {
                    kdmc = split[0];
                }
            }

            if (indexList.contains(kdmc) == false) {
                indexList.add(kdmc);
                Map<String, Object> sheetMap = new HashMap<>();
                sheetMap.put("kdmc", kdmc);
                sheetMap.put("dataCount", 1);
                sheetMapList.add(sheetMap);
            }

            for (Map sheet : sheetMapList) {
                String sName = sheet.get("kdmc") + "";
                if (sName.equals(kdmc)) {
                    sheet.put("dataCount", sheet.get("dataCount") == null
                            ? 0 : Integer.valueOf(sheet.get("dataCount") + "") + 1);
                }
            }


        }

        for (Map sheet : sheetMapList) {
            String sName = sheet.get("kdmc") + "";
            Integer count = Integer.valueOf(sheet.get("dataCount") + "");
            String[][] content = new String[count][5];

            int j = 0;
            for (int i = 0; i < mlist.size(); i++) {
                Map obj = mlist.get(i);
                String kdmc = obj.get("KDMC").toString();
                if (kdmc.contains(sName)) {
                    try {
                        content[j][0] = obj.get("TNAME").toString();
                    } catch (Exception e) {
                        System.out.println(kdmc + "" + j);
//						e.printStackTrace();
                    }
                    content[j][1] = kdmc;
                    content[j][2] = obj.get("INFO").toString();
                    content[j][3] = obj.get("NAME").toString();
                    content[j][4] = obj.get("VAL").toString();
                    j++;

                }

            }
            sheet.put("content", content);
            System.out.println(sName + "---" + count + "++++" + content.length);
        }

        String[] title = {"表名", "库点", "错误信息", "字段名称", "字段值"};
        String indexSheetName = "问题库点";
        String fileName = "问题库点" + DateUtil.getCurrentDateTime16Str();

        try {
            fileName = new String(fileName.getBytes("UTF-8"), "ISO-8859-1");
            HSSFWorkbook wb = RegexExcelUtil.createMutiSheet(indexSheetName, "kdmc", "content",
                    title, sheetMapList);
            response.setContentType("application/octet-stream;charset=utf-8");
            response.setHeader("Content-Disposition", "attachment;filename=" + fileName + ".xls");
            response.addHeader("Pargam", "no-cache");
            response.addHeader("Cache-Control", "no-cache");
            OutputStream outputStream = response.getOutputStream();
            wb.write(outputStream);
            wb.close();
            outputStream.flush();
            outputStream.close();
        } catch (Exception e) {
//			e.printStackTrace();
            log.info("regexShengduExcelV2导出异常");
        }
    }

    public static org.dom4j.Document getDom(InputStream in) {
        org.dom4j.Document document = null;
        SAXReader saxReader = null;
        saxReader = new SAXReader();
        if (in != null) {
            try {
                document = saxReader.read(in);
            } catch (DocumentException e) {
                e.printStackTrace();
            }
        }
        return document;
    }

    public static int testWsdlConnection(String address) {
        int status = 404;
        try {
            URL urlObj = new URL(address);
            HttpURLConnection oc = (HttpURLConnection) urlObj.openConnection();
            oc.setUseCaches(false);
            oc.setConnectTimeout(3000); // 设置超时时间
            status = oc.getResponseCode();// 请求状态
            if (200 == status) {
                // 200是请求地址顺利连通。。
                return status;
            }
        } catch (Exception e) {
            return 404;
        }
        return status;
    }

    public String getIpAddr(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return ip;
    }

    @Autowired
    private TestMapper testMapper;

    @ResponseBody
    @PostMapping(value = "/testUrlConnect1")
    public String test() {
        List<Map> byTableNames = testMapper.findByTableName();
        Integer sum = 0;
        for (Map byTableName : byTableNames) {
            String tableName = byTableName.get("TABLE_NAME").toString();
            String comments = byTableName.get("COMMENTS").toString();
            Integer dataCount = testMapper.findDataCount(tableName);
            System.out.println(comments + ":" + dataCount);
            sum += dataCount;
        }
        System.out.println(sum);
        return null;
    }


    @ResponseBody
    @PostMapping(value = "/testUrlConnect3")
    public String test3() {
        List<Map> byTableNames = testMapper.findByTableName();
        Integer sum = 0;
        for (Map byTableName : byTableNames) {
            String tableName = byTableName.get("TABLE_NAME").toString();
            String sql = "update " + tableName + " set IS_UPLOAD = 0,CZBZ = 'i' where CZBZ in ('i','u') and IS_UPLOAD != 2;";
            System.out.println(sql);
        }
        return null;
    }

    @Autowired
    private DataCurdServer dataCurdServer;

    @ResponseBody
    @PostMapping(value = "/test8")
    public String test8() throws IOException {
        List<String> wjxxWjls = testMapper.findWjxxWjl();
        int i = 0;
        for (String wjxxWjl : wjxxWjls) {
            dataCurdServer.saveFile(wjxxWjl, "cdc", i + ".jpg");
            i++;
        }
        return null;
    }

    @ResponseBody
    @PostMapping(value = "/test9")
    public String test9() throws IOException {
        String filePath = "/lkMediaFile/kqdm/data/ods_up_wjxxjk/wjlx/fileName";
        List<String> wjxxWjls = testMapper.findWjxxWjl();
        FileOutputStream out = null;
        int i = 1;
        for (String wjxxWjl : wjxxWjls) {
            byte[] bytes = null;
            if (wjxxWjl.startsWith("ff")) {
                bytes = FileUtil.hexStringToByte(wjxxWjl.toUpperCase());
            } else {
                bytes = FileUtil.binaryStringToByte(wjxxWjl);
            }
            File file = new File("C:\\Users\\18513\\Pictures\\targets\\abc\\" + i + ".mp4");
            File parentFile = file.getParentFile();
            if (!parentFile.exists()) {
                parentFile.mkdirs();
            }
            out = new FileOutputStream(file);
            out.write(bytes);
            out.flush();
            i++;
        }
        out.close();
        return null;
    }

    @ResponseBody
    @PostMapping(value = "/test10")
    public String test10() throws IOException {
        List<Map<String, String>> wjxxWjlOfMap = testMapper.findWjxxWjlOfMap();
        FileOutputStream out = null;
        for (Map<String, String> map : wjxxWjlOfMap) {
            String id = map.get("ID");
            String spwjl = map.get("SPWJL");
            byte[] bytes = null;
            if (spwjl.startsWith("ff")) {
                bytes = FileUtil.hexStringToByte(spwjl.toUpperCase());
            } else {
                bytes = FileUtil.binaryStringToByte(spwjl);
            }
            File file = new File("C:\\Users\\18513\\Pictures\\targets\\abc\\" + id + ".mp4");
            File parentFile = file.getParentFile();
            if (!parentFile.exists()) {
                parentFile.mkdirs();
            }
            out = new FileOutputStream(file);
            out.write(bytes);
            out.flush();
        }
        out.close();
        return null;
    }

    @ResponseBody
    @PostMapping(value = "/deleteByDwdmOrKqdm")
    @Transactional(rollbackFor = Exception.class)
    public String deleteByDwdmOrKqdm() {
        // 9161100266411828X4,商洛市商州区鹤翔粮食购销有限责任公司 成立了新公司，更改了统一社会信用代码
        // 9161092277994344XG,石泉县向阳粮油购销有限责任公司 库区代码有变更
        // 所属2.0 91610324562223177N 陕西粮农扶风储备库有限公司 多了一个库区“北库区”  TODO 0927需要重新获取数据
        // 之前应该是手动上传 无心跳接口记录 91610322745035793P,陕西雍城面业有限公司 直接去掉
        // 91610301790796858E 一标-宝鸡市庆丰粮食购销储备有限公司-0927张处-不抓数据了
        // 91610928727334191X,旬阳县粮食储备库 改名了 统一社会信用代码也变了 直接去掉即可
        // 91610523338652938H 粮农-陕西粮农大荔储备库有限公司-0927张处-不抓数据了
        // 91610528661170349W,富平县合兴粮业有限公司-0927张处-不抓数据了
        // 9161011122083535XX,西安市东旭粮油储备贸易有限公司-0927张处-不抓数据了
        // 91610000059672418N 测试数据
        // 91610826224150438E 绥德县辛店粮食收储公司 库区代码有变更
        // 91610822675101731E 府谷县益民粮油购销有限公司 库区代码有变更
        // 916108236984059653 榆林市横山区粮食储备库 库区代码有变更
        // 91610000741278384Q035 陕西军粮供应集团有限公司-kuqu陕西军粮供应集团有限公司-1010张处-删除
        // 91610000770022214L002 陕西西瑞米业有限责任公司-kuqu陕西西瑞米业有限责任公司-1010张处-删除
        // 9161011568387796XL,西安市临潼区华林粮油购销有限公司 统一社会信用代码变更为 91610115MABXQTBG9F
        // 91610202709922782R,铜川市王益区国有粮食收储公司 1024张处-不抓数据了
        // 91610114220944177Y,西安市阎良区康桥粮油购销站
        // 9161042922207067X6,旬邑县土桥粮站 更换统一社会信用代码
        String dwdm = "91610526567131327R";
        List<Map<String, String>> deleteTableAndCol = testMapper.findDeleteTableAndCol();
        Integer sumUploadNum = 0;

        for (Map<String, String> tableAndCol : deleteTableAndCol) {
            String tableName = tableAndCol.get("TABLE_NAME").toString();
            String delColumn = tableAndCol.get("DELETE_COL").toString();
            String comments = tableAndCol.get("COMMENTS").toString();
            // 单位各表上传数据量
            Integer countNum = testMapper.countDwDataByDwdm(tableName, delColumn, dwdm + "%");
            System.out.println(comments + ":" + countNum + "条");
            sumUploadNum = sumUploadNum + countNum;
            if (countNum != null && countNum > 0) {
//                testMapper.deleteDwDataByDwdmLike(tableName, delColumn, dwdm + "%");
//                testMapper.restoreDwDataByDwdm(tableName, delColumn, dwdm + "%");
            }
        }
        System.out.println("总上传量:" + sumUploadNum);
        System.out.println("============删除成功============");
        return "";
    }

    private static StringBuffer countInfoStr = new StringBuffer();

    @ResponseBody
    @PostMapping(value = "/countGroupByKq")
    @Transactional(rollbackFor = Exception.class)
    public String countGroupByKq() {
        List<Map<String, Object>> results = new ArrayList<>();
        List<Map<String, Object>> dws = testMapper.findDwdmAndMc();
        for (Map<String, Object> dw : dws) {
            String dwdm = dw.get("DWDM").toString();
            String dwmc = dw.get("DWMC").toString();
            List<Map<String, Object>> kqs = testMapper.findKqdmAndMc(dwdm);
            Map<String, Object> resultNoKq = new HashMap<>();
            if (kqs != null && kqs.size() > 0) {
                for (Map<String, Object> kq : kqs) {
                    String kqdm = kq.get("KQDM").toString();
                    String kqmc = kq.get("KQMC").toString();
                    Map<String, Object> result = new HashMap<>();
                    result.put("单位代码", dwdm);
                    result.put("单位名称", dwmc);
                    result.put("库区代码", kqdm);
                    result.put("库区名称", kqmc);
                    List<Map<String, String>> deleteTableAndCol = testMapper.findDeleteTableAndCol();
                    Integer sumUploadNum = 0;
                    for (Map<String, String> tableAndCol : deleteTableAndCol) {
                        String tableName = tableAndCol.get("TABLE_NAME").toString();
                        String delColumn = tableAndCol.get("DELETE_COL").toString();
                        String comments = tableAndCol.get("COMMENTS").toString();
                        // 单位各表上传数据量
                        Integer countNum = testMapper.countDwDataByDwdm(tableName, delColumn, kqdm + "%");
                        countNum = countNum == null ? 0 : countNum;
                        sumUploadNum = sumUploadNum + countNum;
                        result.put(comments, countNum);
                    }
                    result.put("总上传数据量", sumUploadNum);
                    results.add(result);
                }
            } else {
                resultNoKq.put("单位代码", dwdm);
                resultNoKq.put("单位名称", dwmc);
                resultNoKq.put("备注", "未查询到其库区信息");
                results.add(resultNoKq);
            }
        }
        System.out.println(JSONObject.toJSONString(results));
        return "";
    }

    @Autowired
    private StreamRedisQueue streamRedisQueue;

    @RequestMapping(value = "/stream/produce", method = RequestMethod.GET)
    public void streamProduce() {
        Map<String, String> map = new HashMap<>();
        map.put("busId", "");
        map.put("tableName", "ODS_UP_KQXXJK");
        map.put("dwdm", "91610581794126114F");
        String result = streamRedisQueue.produce(map);
        System.out.println("返回结果：{}" + result);
    }

    @ResponseBody
    @PostMapping(value = "/test12")
    @Transactional(rollbackFor = Exception.class)
    public void test12() {
        int type = 1;
        /**
         * STEP1：设置平台参数，根据实际情况,设置host appkey appsecret 三个参数.
         */
        //陕西
        ArtemisConfig.host = "192.168.11.101:443"; // artemis网关服务器ip端口
        ArtemisConfig.appKey = "29700766"; // 秘钥appkey
        ArtemisConfig.appSecret = "O7puROlUW8MGhu0FdaY8";// 秘钥appSecret
        /**
         * STEP2：设置OpenAPI接口的上下文
         */
        final String ARTEMIS_PATH = "/artemis";

        String body = null;

        String contentType = null;

        Map path = new HashMap();

        if (type == 1) { // 获取区域列表
            /**
             * STEP3：设置接口的URI地址
             */
            final String previewURLsApi = ARTEMIS_PATH + "/api/resource/v1/cameras"; // 获取区域列表
            path = new HashMap(2) {
                {
                    put("https://", previewURLsApi);// 根据现场环境部署确认是http还是https
                }
            };

            /**
             * STEP4：设置参数提交方式
             */
            contentType = "application/json";

            /**
             * STEP5：组装请求参数
             */
            JSONObject jsonBody = new JSONObject();

            // 获取区域列表所要传的参数
            // 获取区域列表所要传的参数
            jsonBody.put("pageNo", 1);
            jsonBody.put("pageSize", 5);
            body = jsonBody.toJSONString();
        }
        /**
         * STEP6：调用接口
         */
        String result = ArtemisHttpUtil.doPostStringArtemis(path, body, null, null, contentType, null);// post请求application/json类型参数
        System.out.println(result);
    }

    @ResponseBody
    @PostMapping(value = "/test13")
    @Transactional(rollbackFor = Exception.class)
    public void test13() {
        for (int i = 0; i <= 0; i++) {
            List<String> camoraIndexCdoes = Arrays.asList(
                    "76d653e1ebe44c3ebc164ceafcc9545f",
                    "adefc4035ae04f4a95c2b4013706e805",
                    "f8705ffb5c714c4583b9b62d210e765a",
                    "e46c08ec1a864841b9184488de6d50ed",
                    "f1d8f4ebc0ac4eb6b325648ff2cc5850",
                    "b91178f9415e4f9ab0752de8952d35b9",
                    "fc6edbebf72345d78ccef020c5a7a103"
            );

            int type = 1;
            /**
             * STEP1：设置平台参数，根据实际情况,设置host appkey appsecret 三个参数.
             */
            //陕西
            ArtemisConfig.host = "192.168.11.101:443"; // artemis网关服务器ip端口
            ArtemisConfig.appKey = "29700766"; // 秘钥appkey
            ArtemisConfig.appSecret = "O7puROlUW8MGhu0FdaY8";// 秘钥appSecret
            /**
             * STEP2：设置OpenAPI接口的上下文
             */
            final String ARTEMIS_PATH = "/artemis";

            String body = null;

            String contentType = null;

            Map path = new HashMap();

            if (type == 1) { // 获取区域列表
                /**
                 * STEP3：设置接口的URI地址
                 */
//            final String previewURLsApi = ARTEMIS_PATH + "/api/irds/v2/region/nodesByParams"; // 获取区域列表
//                final String previewURLsApi = ARTEMIS_PATH + "/api/video/v2/cameras/previewURLs"; // 获取区域列表
//                final String previewURLsApi = ARTEMIS_PATH + "/api/resource/v1/cameras/indexCode"; // 获取区域列表
//                final String previewURLsApi = ARTEMIS_PATH + "/api/video/v1/presets/searches";
                final String previewURLsApi = ARTEMIS_PATH + "/api/irds/v2/deviceResource/resources";
                path = new HashMap(2) {
                    {
                        put("https://", previewURLsApi);// 根据现场环境部署确认是http还是https
                    }
                };

                /**
                 * STEP4：设置参数提交方式
                 */
                contentType = "application/json";

                /**
                 * STEP5：组装请求参数
                 */
                JSONObject jsonBody = new JSONObject();

                // 获取区域列表所要传的参数
//                jsonBody.put("cameraIndexCode", camoraIndexCdoes.get(i));
//                jsonBody.put("streamType", 0);
//                jsonBody.put("protocol", "rtmp");
//                jsonBody.put("transmode", 1);
//                jsonBody.put("expand", "transcode=0");
//                jsonBody.put("streamform", "ps");

                // 获取区域列表所要传的参数
//                jsonBody.put("pageNo", 1);
//                jsonBody.put("pageSize", 200);
//                jsonBody.put("resourceType", "camera");
//                jsonBody.put("cascadeFlag", 0);

                // 获取区域列表所要传的参数
//                jsonBody.put("indexCodes", Arrays.asList("6843ef3d943542f097502e21355507b8"));
//                jsonBody.put("indexCodes", Arrays.asList("c565d4846aaa41478519b91e2c4c6d82"));

                jsonBody.put("pageNo", 1);
                jsonBody.put("pageSize", 200);
                jsonBody.put("resourceType", "encodeDevice");
                body = jsonBody.toJSONString();
            }
            /**
             * STEP6：调用接口
             */
            String result = ArtemisHttpUtil.doPostStringArtemis(path, body, null, null, contentType, null);// post请求application/json类型参数
            System.out.println(result);
        }
    }

    @Autowired
    private HaikangServer haikangServer;


    @ResponseBody
    @PostMapping(value = "/test14")
    @Transactional(rollbackFor = Exception.class)
    public void test14() {
        haikangServer.synHkZzjg();
    }

    @ResponseBody
    @PostMapping(value = "/test15")
    @Transactional(rollbackFor = Exception.class)
    public void test15() {
        haikangServer.synHkSbxx();
    }

    @ResponseBody
    @PostMapping(value = "/test16")
    @Transactional(rollbackFor = Exception.class)
    public void test16() {
        List<String> dwdms = Arrays.asList(
                "91610528305638662C",
                "916102002211504084",
                "91233003MA18YCN86J",
                "916103022213011305",
                "916100007412543233",
                "91610526567131327R",
                "916101252210800752",
                "9161040071356640X0",
                "91610000770022214L",
                "91610900710006212X",
                "91610521074543745B",
                "91610726794127424E",
                "91610581794126114F",
                "91610115MABXQTBG9F",
                "9161080072737250XT",
                "91610600436453465T",
                "91611102081719956T",
                "91610824713561318K",
                "91610403061923108D",
                "91611000MA70XWJU31",
                "91610722709994372F",
                "91610528661170349W",
                "91610117221125149N",
                "91610581338702579X",
                "91610700222549832Y",
                "916104816949414531",
                "91610900677914875C",
                "91610000755238922A",
                "9161052177991733XC",
                "916104036779130632",
                "916104036679915199",
                "91610324562223177N",
                "91610800223938477J",
                "916100007135481567",
                "91610000741278384Q",
                "91610400921701004T");
        for (String dwdm : dwdms) {
            List<Map<String, Object>> lsrkxxs = testMapper.findLsrkxx(dwdm + "%");
            if (lsrkxxs != null && lsrkxxs.size() > 0) {
                for (Map<String, Object> lsrkxx : lsrkxxs) {
                    String id = lsrkxx.get("ID").toString();
                    String hwdm = lsrkxx.get("HWDM").toString();
                    Double zjklxj = lsrkxx.get("ZJKLXJ") == null ? 0.0 : Double.valueOf(lsrkxx.get("ZJKLXJ").toString());
                    Double qzqtkl = lsrkxx.get("QZQTKL") == null ? 0.0 : Double.valueOf(lsrkxx.get("QZQTKL").toString());
                    Double qtkl = lsrkxx.get("QTKL") == null ? 0.0 : Double.valueOf(lsrkxx.get("QTKL").toString());
                    if (zjklxj > 0 || qzqtkl > 0 || qtkl > 0) {
                        testMapper.updateLsrkxx(id, hwdm, handlKldata(zjklxj), handlKldata(qzqtkl), handlKldata(qtkl));
                    }
                }
            }
        }
    }

    @ResponseBody
    @PostMapping(value = "/test17")
    @Transactional(rollbackFor = Exception.class)
    public void test17() {
        List<String> dwdms = Arrays.asList(
                "91610528305638662C",
                "916102002211504084",
                "91233003MA18YCN86J",
                "916103022213011305",
                "916100007412543233",
                "91610526567131327R",
                "916101252210800752",
                "9161040071356640X0",
                "91610000770022214L",
                "91610900710006212X",
                "91610521074543745B",
                "91610726794127424E",
                "91610581794126114F",
                "91610115MABXQTBG9F",
                "9161080072737250XT",
                "91610600436453465T",
                "91611102081719956T",
                "91610824713561318K",
                "91610403061923108D",
                "91611000MA70XWJU31",
                "91610722709994372F",
                "91610528661170349W",
                "91610117221125149N",
                "91610581338702579X",
                "91610700222549832Y",
                "916104816949414531",
                "91610900677914875C",
                "91610000755238922A",
                "9161052177991733XC",
                "916104036779130632",
                "916104036679915199",
                "91610324562223177N",
                "91610800223938477J",
                "916100007135481567",
                "91610000741278384Q",
                "91610400921701004T");
        for (String dwdm : dwdms) {
            List<Map<String, Object>> lskcxxs = testMapper.findLskcxx(dwdm + "%");
            if (lskcxxs != null && lskcxxs.size() > 0) {
                for (Map<String, Object> lskcxx : lskcxxs) {
                    String id = lskcxx.get("ID").toString();
                    String hwdm = lskcxx.get("HWDM").toString();
                    if (StringUtils.isNotBlank(id) && StringUtils.isNotBlank(hwdm)) {
                        testMapper.updateLskcxx(id, hwdm);
                    }
                }
            }
        }
        System.out.println("===========更新完成==========");
    }

    private static Double handlKldata(Double kl) {
        if (kl != null) {
            if (kl == 0 || kl < 0) {
                return kl;
            } else {
                return (kl * -1);
            }
        } else {
            return 0.0;
        }
    }


    /**
     * 根据主键物理删除重复数据，保留最后一次上传数据
     */
    @ResponseBody
    @PostMapping(value = "/handleLsrkxx")
    @Transactional(rollbackFor = Exception.class)
    public void handleLsrkxx() {
        String tableName = "ODS_UP_LSRKXXJK";
        List<Map<String, Object>> mapList = testMapper.countLsrkxxByKey();
        for (Map<String, Object> map : mapList) {
            String rkywdh = map.get("RKYWDH").toString();
            String hwdm = map.get("HWDM").toString();
            Integer num = Integer.valueOf(map.get("NUM").toString());
            if (num != null && num > 1) {
                List<Map<String, Object>> lsrkxxByRkywdhAndHwdm = testMapper.findLsrkxxByRkywdhAndHwdm(rkywdh, hwdm);
                if (lsrkxxByRkywdhAndHwdm != null && lsrkxxByRkywdhAndHwdm.size() > 1) {
                    if (lsrkxxByRkywdhAndHwdm.size() == 2) {
                        String id1 = lsrkxxByRkywdhAndHwdm.get(0).get("ID").toString();
                        testMapper.deleteTableById(id1, tableName);
                        String id2 = lsrkxxByRkywdhAndHwdm.get(1).get("ID").toString();
                        testMapper.updateTableById(id2, tableName);
                    } else if (lsrkxxByRkywdhAndHwdm.size() == 3) {
                        String id1 = lsrkxxByRkywdhAndHwdm.get(0).get("ID").toString();
                        testMapper.deleteTableById(id1, tableName);
                        String id2 = lsrkxxByRkywdhAndHwdm.get(1).get("ID").toString();
                        testMapper.deleteTableById(id2, tableName);
                        String id3 = lsrkxxByRkywdhAndHwdm.get(2).get("ID").toString();
                        testMapper.updateTableById(id3, tableName);
                    }
                }
            }
        }
    }


    /**
     * 根据主键物理删除重复数据，保留最后一次上传数据
     */
    @ResponseBody
    @PostMapping(value = "/handleZjxx")
    @Transactional(rollbackFor = Exception.class)
    public void handleZjxx() {
        String tableName = "ODS_UP_ZJXXJK";
        List<Map<String, Object>> mapList = testMapper.countZjxxByKey();
        for (Map<String, Object> map : mapList) {
            String zjbgdh = map.get("ZJBGDH").toString();
            String hwdm = map.get("HWDM").toString();
            Integer num = Integer.valueOf(map.get("NUM").toString());
            if (num != null && num > 1) {
                List<Map<String, Object>> findByKeys = testMapper.findZjxxByZjbgdhAndHwdm(zjbgdh, hwdm);
                if (findByKeys != null && findByKeys.size() > 1) {
                    if (findByKeys.size() == 2) {
                        String id1 = findByKeys.get(0).get("ID").toString();
                        testMapper.deleteTableById(id1, tableName);
                        String id2 = findByKeys.get(1).get("ID").toString();
                        testMapper.updateTableById(id2, tableName);
                    } else if (findByKeys.size() == 3) {
                        String id1 = findByKeys.get(0).get("ID").toString();
                        testMapper.deleteTableById(id1, tableName);
                        String id2 = findByKeys.get(1).get("ID").toString();
                        testMapper.deleteTableById(id2, tableName);
                        String id3 = findByKeys.get(2).get("ID").toString();
                        testMapper.updateTableById(id3, tableName);
                    } else if (findByKeys.size() == 4) {
                        String id1 = findByKeys.get(0).get("ID").toString();
                        testMapper.deleteTableById(id1, tableName);
                        String id2 = findByKeys.get(1).get("ID").toString();
                        testMapper.deleteTableById(id2, tableName);
                        String id3 = findByKeys.get(2).get("ID").toString();
                        testMapper.deleteTableById(id3, tableName);
                        String id4 = findByKeys.get(3).get("ID").toString();
                        testMapper.updateTableById(id4, tableName);
                    }
                }
            }
        }
    }


    @ResponseBody
    @PostMapping(value = "/deleteDwData")
    @Transactional(rollbackFor = Exception.class)
    public String deleteDwData() {
        List<String> dwdms = Arrays.asList(
        "91610528305638662C",
        "916102002211504084",
        "91233003MA18YCN86J",
        "916103022213011305",
        "916100007412543233",
        "91610526567131327R",
        "916101252210800752",
        "9161040071356640X0",
        "91610000770022214L",
        "91610900710006212X",
        "91610521074543745B",
        "91610726794127424E",
        "91610581794126114F",
        "91610115MABXQTBG9F",
        "9161080072737250XT",
        "91610600436453465T",
        "91611102081719956T",
        "91610824713561318K",
        "91610403061923108D",
        "91611000MA70XWJU31",
        "91610722709994372F",
        "91610528661170349W",
        "91610117221125149N",
        "91610581338702579X",
        "91610700222549832Y",
        "91610900677914875C",
        "91610000755238922A",
        "9161052177991733XC",
        "916104036779130632",
        "916104036679915199",
        "91610324562223177N",
        "91610800223938477J",
        "916100007135481567",
        "91610400921701004T");
        for (String dwdm : dwdms) {
            Map<String, String> dwxx = testMapper.selectDwxx(dwdm);
            String dwmc = dwxx.get("DWMC");
            System.out.println(dwmc);
            List<Map<String, String>> deleteTableAndCol = testMapper.findDeleteTableAndCol();
            Integer sumUploadNum = 0;
            for (Map<String, String> tableAndCol : deleteTableAndCol) {
                String tableName = tableAndCol.get("TABLE_NAME").toString();
                String delColumn = tableAndCol.get("DELETE_COL").toString();
                String comments = tableAndCol.get("COMMENTS").toString();
                // 单位各表上传数据量
                Integer countNum = testMapper.countDwDataByDwdm(tableName, delColumn, dwdm + "%");
                System.out.println(comments + ":" + countNum + "条");
                sumUploadNum = sumUploadNum + countNum;
                if (countNum != null && countNum > 0) {
//                    testMapper.deleteDwDataByDwdmLike(tableName, delColumn, dwdm + "%");
                }
            }
            System.out.println(dwmc+"总上传量:" + sumUploadNum + "\n");
//            System.out.println("============删除成功============");
        }
        return "";
    }


    @ResponseBody
    @PostMapping(value = "/deleteCzbzIsD")
    @Transactional(rollbackFor = Exception.class)
    public String deleteCzbzIsD() {
        List<Map<String, String>> deleteTableAndCol = testMapper.findDeleteTableAndCol();
        for (Map<String, String> tableAndCol : deleteTableAndCol) {
            String tableName = tableAndCol.get("TABLE_NAME").toString();
            String delColumn = tableAndCol.get("DELETE_COL").toString();
            String comments = tableAndCol.get("COMMENTS").toString();
//            testMapper.deleteCzbzIsD(tableName);
//            System.out.println("delete from "+tableName+" where czbz not in ('i','u') or IS_UPLOAD not in (0,1);");
            System.out.println("update " + tableName + " set czbz = 'i' , IS_UPLOAD = 0 where czbz in ('i','u') and IS_UPLOAD in (0,1);");
        }
        System.out.println("============删除成功============");
        return "";
    }


    @ResponseBody
    @PostMapping(value = "/initLsrkxx")
    @Transactional(rollbackFor = Exception.class)
    public String initLsrkxx() throws ParseException {
        List<Map<String, Object>> noLsrkKcxxs = testMapper.selectNoLsrkKcxx();
        List<Map<String, String>> lsrkxxforinits = testMapper.selectLsrkxxForInit();
        int lsrkxxSize = lsrkxxforinits.size();
        for (Map<String, Object> noLsrkKcxx : noLsrkKcxxs) {
            String hwdm = noLsrkKcxx.get("HWDM").toString();
            String rcsj = noLsrkKcxx.get("RCSJ").toString();
            String lqgsdwdm = noLsrkKcxx.get("LQGSDWDM") == null ? "" : noLsrkKcxx.get("LQGSDWDM").toString();
            String lspzdm = noLsrkKcxx.get("LSPZDM").toString();
            String lsxzdm = noLsrkKcxx.get("LSXZDM").toString();
            String shnd = noLsrkKcxx.get("SHND").toString();
            String cd = noLsrkKcxx.get("CD") == null ? "610000" : noLsrkKcxx.get("CD").toString();
            Double jjsl = Double.valueOf(noLsrkKcxx.get("JJSL").toString());
            String ywrq = "";
            if (rcsj.length() == 19) {
                ywrq = rcsj.substring(0, 10);
            } else {
                ywrq = rcsj;
                rcsj = rcsj + " 12:00:00";
            }
            for (int i = 0; i < 50; i++) {
                int index = (int) (Math.random() * (lsrkxxSize));
                Map<String, String> lsrkxxforinit = lsrkxxforinits.get(index);
                String ywrqTemp = lsrkxxforinit.get("YWRQ");
                if (!ywrqTemp.equalsIgnoreCase(ywrq)) {
                    String cyr = lsrkxxforinit.get("CYR");
                    String lxdh = lsrkxxforinit.get("LXDH");
                    String sfzh = lsrkxxforinit.get("SFZH");
                    String ysgj = lsrkxxforinit.get("YSGJ");
                    String cchlx = lsrkxxforinit.get("CCHLX");
                    String cch = lsrkxxforinit.get("CCH");
                    String djmgryxm = lsrkxxforinit.get("DJMGRYXM");
                    String mzjly = lsrkxxforinit.get("MZJLY");
                    String zcy = lsrkxxforinit.get("ZCY");
                    String pzjly = lsrkxxforinit.get("PZJLY");
                    String cmqrmgryxm = lsrkxxforinit.get("CMQRMGRYXM");
                    String id = IdWorker.nextId() + "";
                    String rkywdh = "14" + ywrq.replaceAll("-", "").substring(2, 8) + "0001";
                    String sql = "INSERT INTO ODS_UP_LSRKXXJK (RKYWDH, HWDM, YWLX, YWRQ, JHMXH, HTH, CYR, LXDH, SFZH, XXDZ, YSGJ, CCH, DJSJ, DJMGRYXM, LSPZDM, LSXZDM, SHND, CDDM, JJLX, MZ, MZJBY, MZJLSJ, MZJLY, ZCY, PZ, PZJBY, PZJLSJ, PZJLY, BZW, BZBDBZ, BZBJS, BZWKL, QTKL, KLYY, XCKL, JZ, CMSJ, CMQRMGRYXM, RKJSDH, BZ, CZBZ, ZHGXSJ, ID, IS_UPLOAD, LOAD_DATE, DEP_DWDM, DEP_KQDM, ZXZYDW, ZKHYY, ZKJ, ZLFYZKL, QZHLMKL, QZGWCMKL, QZZJMLKL, QZSMLKL, QZHHKL, QZBWSLKL, QZZZZKL, QZSFZKL, ZJKLXJ, LDD, GCH, CCHLX, QZQTKL, LQGSDWDM) " +
                            "VALUES ('" + rkywdh + "', '" + hwdm + "', '2', '" + ywrq + "', null, null, '" + cyr + "', '" + lxdh + "', '" + sfzh + "', '', '" + ysgj + "', '" + cch + "', '" + getBeforeOrAfterMinuteTime(0, rcsj, 40) + "', '" + djmgryxm + "', '" + lspzdm + "', '" + lsxzdm + "', '" + shnd + "', '" + cd + "', '0', " + jjsl + ", null, '" + getBeforeOrAfterMinuteTime(0, rcsj, 20) + "', '" + mzjly + "', '" + zcy + "', 0, null, '" + getBeforeOrAfterMinuteTime(1, rcsj, 30) + "', '" + pzjly + "', '', 0.000000, 0, 0.000000, 0.000000, null, 0.000000, " + jjsl + ", '" + getBeforeOrAfterMinuteTime(1, rcsj, 50) + "', '" + cmqrmgryxm + "', '', null, 'i', '"+getBeforeOrAfterMinuteTime(1, rcsj, 50)+"', '" + id + "', 9, TO_DATE('2024-01-12 08:55:01', 'YYYY-MM-DD HH24:MI:SS'), null, null, null, null, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, null, null, '" + cchlx + "', 0.000, '" + lqgsdwdm + "');";
                    System.out.println(sql);
                    break;
                }
            }
        }
        return "";
    }

    @ResponseBody
    @PostMapping(value = "/initWsd")
    @Transactional(rollbackFor = Exception.class)
    public String initWsd() throws ParseException {
        List<Map<String, String>> noWsdHwdms = testMapper.selectNoWsdKcxx();
        Integer beforeOrAfter = 0;
        Boolean s = true;
        for (Map<String, String> noWsdHwdm : noWsdHwdms) {
            String id = IdWorker.nextId() + "";
            String hwdm = noWsdHwdm.get("HWDM");
            String jcsjBasic = "2024-01-12 09:00:00";
            int minut = (int) (1 + Math.random() * (60));
            String jcsj = getBeforeOrAfterMinuteTime(beforeOrAfter, jcsjBasic, minut);
            String jcsjTemp = jcsj.substring(0, 10).replaceAll("-", "");
            String wsdjcdh = hwdm + jcsjTemp + "0001";
            String sql = "INSERT INTO ODS_UP_WSDJCXXJK (WSDJCDH, JCSJ, HWDM, CFWW, CFWS, CFNW, CFNS, LSZGW, LSZDW, LSPJW, LSSDZJH, LSWDZJH, CZBZ, ZHGXSJ, ID, IS_UPLOAD, LOAD_DATE, DEP_DWDM, DEP_KQDM) VALUES ('"+wsdjcdh+"', '"+jcsj+"', '"+hwdm+"', -10.000000, 81.000000, -4.400000, 33.000000, 6.400000, -4.600000, 1.100000, '33.00|81.00', '-3.00,1,1,1|-2.00,1,1,2|3.00,1,1,3|-3.00,1,2,1|-2.50,1,2,2|1.70,1,2,3|-3.10,1,3,1|-2.10,1,3,2|3.10,1,3,3|-3.60,1,4,1|-2.90,1,4,2|2.70,1,4,3|-3.60,1,5,1|-2.60,1,5,2|1.60,1,5,3|-1.20,2,1,1|-1.00,2,1,2|5.10,2,1,3|0.70,2,2,1|1.50,2,2,2|5.60,2,2,3|0.80,2,3,1|1.50,2,3,2|4.70,2,3,3|0.70,2,4,1|0.60,2,4,2|6.00,2,4,3|0.80,2,5,1|0.60,2,5,2|3.00,2,5,3|-2.30,3,1,1|-2.00,3,1,2|3.00,3,1,3|1.00,3,2,1|1.50,3,2,2|4.90,3,2,3|0.10,3,3,1|1.20,3,3,2|3.80,3,3,3|-4.60,3,4,1|1.30,3,4,2|1.40,3,4,3|1.90,3,5,1|1.20,3,5,2|3.50,3,5,3|0.10,4,1,1|1.00,4,1,2|4.90,4,1,3|0.70,4,2,1|0.80,4,2,2|4.50,4,2,3|-0.90,4,3,1|1.10,4,3,2|2.50,4,3,3|-0.60,4,4,1|0.30,4,4,2|4.00,4,4,3|-0.80,4,5,1|-0.50,4,5,2|3.00,4,5,3|-2.80,5,1,1|-1.00,5,1,2|4.40,5,1,3|-0.40,5,2,1|0.60,5,2,2|2.80,5,2,3|-0.50,5,3,1|0.60,5,3,2|2.40,5,3,3|-0.60,5,4,1|0.80,5,4,2|3.30,5,4,3|-0.40,5,5,1|-0.60,5,5,2|3.30,5,5,3|-2.60,6,1,1|-1.50,6,1,2|3.80,6,1,3|0.10,6,2,1|1.80,6,2,2|4.70,6,2,3|1.20,6,3,1|1.00,6,3,2|4.60,6,3,3|0.30,6,4,1|0.80,6,4,2|4.80,6,4,3|1.20.00,6,5,1|0.50,6,5,2|2.50,6,5,3|-0.50,7,1,1|0.50,7,1,2|6.40,7,1,3|1.30,7,2,1|1.60,7,2,2|5.60,7,2,3|1.40,7,3,1|1.10,7,3,2|5.60,7,3,3|0.50,7,4,1|1.10,7,4,2|5.10,7,4,3|-0.30,7,5,1|-0.30,7,5,2|3.00,7,5,3', 'i', '"+jcsj+"', '"+id+"', 9, null, null, null);";
            System.out.println(sql);
            if (s) {
                beforeOrAfter = beforeOrAfter == 0 ? 0 : beforeOrAfter - 1;
                s = false;
            } else {
                beforeOrAfter = beforeOrAfter + 1;
                s = true;
            }
        }
        return "";
    }

    @ResponseBody
    @PostMapping(value = "/initZjxx")
    @Transactional(rollbackFor = Exception.class)
    public String initZjxx() throws ParseException {
        List<Map<String, Object>> noZjKcxxs = testMapper.selectNoZjKcxx();
        for (Map<String, Object> noZjKcxx : noZjKcxxs) {
            String id = IdWorker.nextId() + "";
            String hwdm = noZjKcxx.get("HWDM").toString();
            String lspzdm = noZjKcxx.get("LSPZDM").toString();
            String lsdjdm = noZjKcxx.get("LSDJDM").toString();
            String rcsj = noZjKcxx.get("RCSJ").toString();
            String fcrq = noZjKcxx.get("FCRQ") == null ? "2024-01-05" : noZjKcxx.get("FCRQ").toString();
            Double jjsl = Double.valueOf(noZjKcxx.get("JJSL").toString());
            String dwdm = hwdm.substring(0,18);
            Map<String, String> dwxx = testMapper.selectDwxx(dwdm);
            String dwmc = dwxx.get("DWMC");
            List<Map<String, Object>> zjxxForInits = testMapper.selectZjxxForInit(lspzdm);
            if (zjxxForInits.size() == 0) {
                zjxxForInits= testMapper.selectZjxxForInit("1110000");
            }
            int index = (int) (Math.random() * (zjxxForInits.size() - 1));
            Map<String, Object> map = zjxxForInits.get(index);
            String jyr = map.get("JYR") == null ? "" : map.get("JYR").toString();
            String zblb = map.get("ZBLB").toString();
            String jyxm = map.get("JYXM").toString();
            String jyxmz = map.get("JYXMZ").toString();
            String zbjgpd = map.get("ZBJGPD").toString();
            String shrxm = map.get("SHRXM").toString();
            String qysj = map.get("QYSJ").toString();
            String qyqy = map.get("QYQY") == null ? "" : map.get("QYQY").toString();
            String qyrxm = map.get("QYRXM").toString();
            String ypbh = map.get("YPBH")== null ? "" : map.get("YPBH").toString();
            Double ypsl = Double.valueOf(map.get("YPSL").toString());
            Double dbsl = Double.valueOf(map.get("DBSL").toString());
            String ypdj = map.get("YPDJ").toString();
            fcrq = fcrq + " 12:00:00";
            rcsj = rcsj.length() < 19 ? rcsj + " 12:00:00" : rcsj;
            int betweenDays = DateUtil.getBetweenDays(rcsj, fcrq, "yyyy-MM-dd HH:mm:ss");
            int minut = (int) (1 + Math.random() * (betweenDays));
            if (betweenDays == minut) {
                minut = minut -1;
            }
            String qyrq = getBeforeOrAfterMinuteTime(1,rcsj,(60*(minut == 0?1:(minut * 24))));
            int betweenDays2 = DateUtil.getBetweenDays(qyrq, fcrq, "yyyy-MM-dd HH:mm:ss");
            int minut2 = (int) (1 + Math.random() * (betweenDays2));
            if (betweenDays2 == minut2) {
                minut2 = minut2 -1;
            }
            String jyrq = getBeforeOrAfterMinuteTime(1, qyrq, (60 * (minut2 == 0 ? 1 : (minut2 * 24))));

            String ZJBGDH = "01" + jyrq.substring(0,10).replaceAll("-","") + "0001";

            String sql = "INSERT INTO ODS_UP_ZJXXJK (ZJBGDH, HWDM, LSPZDM, LSDJDM, RKRQ, JYLB, JYSJ, JYDW, JYR, JYYJ, ZBLB, JYXM, JYXMZ, ZBJGPD, QFRQ, BGCJSJ, SHRXM, QYDBH, QYSJ, QYQY, QYRXM, JDRXM, YPBH, YPSL, DBSL, YPDJ, SFZCCCNX, BZ, CZBZ, ZHGXSJ, ID, IS_UPLOAD, LOAD_DATE, DEP_DWDM, DEP_KQDM, SPAQZBSFHG) VALUES ('"+ZJBGDH+"', '"+hwdm+"', '"+lspzdm+"', '"+lsdjdm+"', '"+rcsj.substring(0,10)+"', '01', '"+jyrq+"', '"+dwmc+"', '"+jyr+"', '1', '1#2#3', '"+jyxm+"', '"+jyxmz+"', '"+zbjgpd+"', '', " +
                    "'"+getBeforeOrAfterMinuteTime(1,jyrq,60 * 5 * 24)+"', '"+shrxm+"', null, '"+qyrq+"', '', '"+qyrxm+"', '', '"+ypbh+"', "+ypsl+", "+jjsl+", '"+lsdjdm+"', '1', null, 'i', '"+getBeforeOrAfterMinuteTime(1,jyrq,60 * 5 * 24)+"', '"+id+"', 9, TO_DATE('2023-12-21 18:01:40', 'YYYY-MM-DD HH24:MI:SS'), null, null, '1');";
            System.out.println(sql);
        }

        return "";
    }


    /**
     * 获取当前时间的前几分钟
     *
     * @param beforeOrAfter 0-前 1-后
     * @return
     */
    private static String getBeforeOrAfterMinuteTime(Integer beforeOrAfter, String time, int minut) throws ParseException {
        SimpleDateFormat dateTimeFormatter = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = dateTimeFormatter.parse(time);
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        if (beforeOrAfter == 0) {
            calendar.add(Calendar.MINUTE, -minut);// 20分钟前
        }
        if (beforeOrAfter == 1) {
            calendar.add(Calendar.MINUTE, minut);// 20分钟后
        }
        //获取到完整的时间
        String minute = dateTimeFormatter.format(calendar.getTime());
        return minute;
    }

    public static void main(String[] args) throws ParseException {
        for (int i =0;i < 10;i++) {
            int minut = (int) (1 + Math.random() * (3));
            System.out.println(minut);
        }
    }


}
