package com.unis.hlht.cjlksj.server.mapper;


import com.unis.hlht.cjlksj.server.utils.ClobUtils;
import com.unis.hlht.cjlksj.server.utils.DateUtil;
import com.unis.hlht.cjlksj.server.utils.IdWorker;
import com.unis.hlht.cjlksj.server.utils.MapUtils;

import org.apache.ibatis.annotations.InsertProvider;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.SelectProvider;
import org.apache.ibatis.annotations.UpdateProvider;
import org.apache.ibatis.jdbc.SQL;
import org.springframework.transaction.annotation.Transactional;

import java.sql.Clob;
import java.sql.SQLException;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Set;

@Mapper
public interface GeneralMapper /*extends MyMapper*/ {

    /**
     * 根据逻辑主键获取数据
     *
     * @param tableName    表名
     * @param keys         逻辑主键
     * @param tableDataMap 粮库上传的数据
     * @return 表中数据
     */
    @SelectProvider(type = SqlProvider.class, method = "getByLogickey")
    List<Map> getByLogickey(String tableName, List<String> keys, Map tableDataMap);

    /**
     * 根据主键做逻辑删除操作
     *
     * @param id        数据主键
     * @param tableName 表名
     */
    @UpdateProvider(type = SqlProvider.class, method = "deleteByPrimaryKey")
    void deleteByPrimaryK(String id, String tableName);

    /**
     * 根据主键更新表数据
     *
     * @param id           数据主键
     * @param tableName    表名
     * @param tableDataMap 粮库上传的数据
     * @param set
     */
    @UpdateProvider(type = SqlProvider.class, method = "updateByPrimaryKey")
    void updateByPrimaryK(Map tableDataMap);

    /**
     * 插入数据
     *
     * @param tableDataMap 粮库上传的数据
     */
    @InsertProvider(type = SqlProvider.class, method = "insertData")
    void insertData(Map tableDataMap);

    class SqlProvider {

        public String getByLogickey(String tableName, List<String> keys, Map tableDataMap) {
            StringBuilder sql = new StringBuilder();
            sql.append("select id, czbz from ");
            sql.append(tableName);
            sql.append(" where 1 = 1 ");
            for (String key : keys) {
                sql.append(" and " + key + " = ");
                Object columnValue = MapUtils.getObjectIgnoreCase(tableDataMap, key);
                if (columnValue instanceof Integer || columnValue instanceof Long || columnValue instanceof Double
                        || columnValue instanceof Float || columnValue instanceof Boolean) {
                    sql.append(columnValue);
                } else {
                    sql.append("'");
                    sql.append(columnValue);
                    sql.append("'");
                }
            }
            return sql.toString();
        }

        @SuppressWarnings("unchecked")
        public String deleteByPrimaryKey(String id, String tableName) {
            StringBuilder sql = new StringBuilder();
            sql.append("update ");
            sql.append(tableName);
            sql.append(" set czbz = 'd',is_upload = 0 where id = '");
            sql.append(id);
            sql.append("'");
            return sql.toString();
        }

        @SuppressWarnings("unchecked")
        public String updateByPrimaryKey(Map tableDataMap) {
            SQL sql = new SQL();
            sql.UPDATE(tableDataMap.get("tableName") + "");
            Set<String> keySet = tableDataMap.keySet();
            for (String cloumn : keySet) {
                Object columnValue = tableDataMap.get(cloumn);
                if (!cloumn.equalsIgnoreCase("tableName") && !cloumn.equalsIgnoreCase("id")) {
                    if (cloumn.equalsIgnoreCase("czbz")) {
                        sql.SET(cloumn + "=" + "'u'");
                    } else if (columnValue instanceof Integer || columnValue instanceof Long || columnValue instanceof Double
                            || columnValue instanceof Float || columnValue instanceof Boolean) {
                        sql.SET(cloumn + "=" + columnValue);
                    } else if (ClobUtils.isClob(tableDataMap.get("tableName") + "", cloumn)) {
                        sql.SET(cloumn + "=#{" + cloumn + ",jdbcType=CLOB}");
                    } else if (columnValue instanceof String){
                        sql.SET(cloumn + "=" + "'" + (((String) columnValue).trim()) + "'");
                    } else {
                        sql.SET(cloumn + "=" + "'" + columnValue + "'");
                    }
                }
            }
            sql.SET("is_upload = 0");
            sql.SET("load_date = DATE_FORMAT('" + DateUtil.getDateTime() + "','%Y-%m-%d %H:%i:%s')");
            sql.WHERE("id = '" + tableDataMap.get("id") + "'");
            return sql.toString();
        }

        @SuppressWarnings("unchecked")
        public String insertData(Map tableDataMap) {
            SQL sql = new SQL();
            sql.INSERT_INTO(tableDataMap.get("tableName") + "");
            //sql.VALUES("id", "'" +IdWorker.nextId() + "'");
            Set<String> keySet = tableDataMap.keySet();
            for (String cloumn : keySet) {
                Object columnValue = tableDataMap.get(cloumn);
                if (!cloumn.equalsIgnoreCase("tableName")) {
                    if (cloumn.equalsIgnoreCase("czbz")) {
                        sql.VALUES(cloumn, "'i'");
                    } else if (columnValue instanceof Integer || columnValue instanceof Long || columnValue instanceof Double
                            || columnValue instanceof Float || columnValue instanceof Boolean) {
                        sql.VALUES(cloumn, "" + columnValue);
                    } else if (ClobUtils.isClob(tableDataMap.get("tableName") + "", cloumn)) {
                        sql.VALUES(cloumn, "#{" + cloumn + ",jdbcType=CLOB}");
                    } else if (columnValue instanceof String){
                        sql.VALUES(cloumn, "'" + (((String) columnValue).trim()) + "'");
                    } else {
                        sql.VALUES(cloumn, "'" + columnValue + "'");
                    }
                }
            }
            sql.VALUES("is_upload", "0");
            sql.VALUES("load_date", "DATE_FORMAT('" + DateUtil.getDateTime() + "','%Y-%m-%d %H:%i:%s')");
            return sql.toString();
        }
    }
}
