package com.unis.hlht.cjlksj.server.server;

import com.unis.hlht.cjlksj.server.mapper.GeneralMapper;
import com.unis.hlht.cjlksj.server.utils.FileUtil;
import com.unis.hlht.cjlksj.server.utils.IdWorker;
import com.unis.hlht.cjlksj.server.utils.MapUtils;
import com.unis.hlht.cjlksj.server.utils.OrderID;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.sql.DataSource;
import java.io.File;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.util.List;
import java.util.Map;
import java.util.SplittableRandom;

/**
 * @Auther: 蒋青茂
 * @Date: 2019-5-8 11:07
 */
@Log4j2
@Service
@SuppressWarnings("all")
public class DataCurdServer {

    @Autowired
    private DataSource dataSource;

    @Autowired
    private GeneralMapper generalMapper;

    @Value("${baseFilePath}")
    private String baseFilePath;

    /**
     * 根据逻辑主键获取数据
     *
     * @param tableName    表名
     * @param keys         逻辑主键
     * @param tableDataMap 粮库上传的数据
     * @return 表中数据
     */
    @Transactional
    public List<Map> getByLogickey(String tableName, List<String> keys, Map tableDataMap) {
        return generalMapper.getByLogickey(tableName, keys, tableDataMap);
    }

    /**
     * 根据主键做逻辑删除操作
     *
     * @param id        数据主键
     * @param tableName 表名
     */
    @Transactional
    public void deleteByPrimaryK(String id, String tableName) {
        generalMapper.deleteByPrimaryK(id, tableName);
    }

    /**
     * 根据主键更新表数据
     *
     * @param id           数据主键
     * @param tableName    表名
     * @param tableDataMap 粮库上传的数据
     * @param set
     */
    @Transactional
    public void updateByPrimaryK(Map tableDataMap, String tableName) {
        if ("ODS_UP_WJXXJK".equalsIgnoreCase(tableName)) {
            wjUpdate(tableDataMap);
        } else if ("ODS_UP_WSDJCXXJK".equalsIgnoreCase(tableName)) {
            wsdUpdate(tableDataMap);
        } else if ("ODS_UP_CNSPTXXXJK".equalsIgnoreCase(tableName)) {
            cnsptxUpdate(tableDataMap);
        } else if ("ODS_UP_SPJKYCSJGJJBXXJK".equalsIgnoreCase(tableName)) {
            spjkycsjgjUpdate(tableDataMap);
        }
    }

    /**
     * 插入数据
     *
     * @param tableName    表名
     * @param tableDataMap 粮库上传的数据
     */
    public void insertData(Map tableDataMap, String tableName) {
        if ("ODS_UP_WJXXJK".equalsIgnoreCase(tableName)) {
            wjInsert(tableDataMap);
        } else if ("ODS_UP_WSDJCXXJK".equalsIgnoreCase(tableName)) {
            wsdInsert(tableDataMap);
        } else if ("ODS_UP_CNSPTXXXJK".equalsIgnoreCase(tableName)) {
            cnsptxInsert(tableDataMap);
        } else if ("ODS_UP_SPJKYCSJGJJBXXJK".equalsIgnoreCase(tableName)) {
            spjkycsjgjInsert(tableDataMap);
        }
    }


    // 文件上传
    private void wjInsert(Map tableDataMap) {
        //表数据
        log.error("图片信息持久化开始");
        Connection connection = null;
        PreparedStatement pre = null;
        try {
            String wjl = MapUtils.getObjectIgnoreCase(tableDataMap, "WJL") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "WJL"));
            String kqdm = MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM"));
            String zhgxsj = MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ"));
            String wjlx = MapUtils.getObjectIgnoreCase(tableDataMap, "WJLX") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "WJLX"));
            String wjmc = MapUtils.getObjectIgnoreCase(tableDataMap, "WJMC") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "WJMC"));
            if (StringUtils.isNotBlank(wjl) && StringUtils.isNotBlank(kqdm) && StringUtils.isNotBlank(zhgxsj)
            && StringUtils.isNotBlank(wjlx) && StringUtils.isNotBlank(wjmc)) {
                // 保存图片到服务器
                String filePathAndName = saveWjxxjkFile(wjl, kqdm, zhgxsj, wjlx, wjmc);
                String sql = "insert into ODS_UP_WJXXJK (ID,KQDM,WJMC,WJLX,WJL,ZHGXSJ,CZBZ,IS_UPLOAD) values (?,?,?,?,?,?,?,0)";
                connection = dataSource.getConnection();
                pre = connection.prepareStatement(sql);
                //表数据
                pre.setString(1, String.valueOf(IdWorker.nextId()));
                pre.setString(2, kqdm);
                pre.setString(3, wjmc);
                pre.setString(4, wjlx);
                pre.setString(5, filePathAndName);
                pre.setString(6, zhgxsj);
                pre.setString(7, MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ")));
                pre.addBatch();
                pre.executeBatch();
                connection.commit();
                log.error("文件信息持久化结束");
            }
        } catch (Exception e) {
            if (connection != null) {
                try {
                    connection.rollback();
                } catch (Exception e1) {
                    throw new RuntimeException(e1.getMessage());
                }
            }
            throw new RuntimeException(e.getMessage());
        } finally {
            if (pre != null) {
                try {
                    pre.close();
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                } finally {
                    if (connection != null) {
                        try {
                            connection.close();
                        } catch (Exception e) {
                            throw new RuntimeException(e.getMessage());
                        }
                    }
                }
            }
        }
    }


    // 文件上传
    private void wjUpdate(Map tableDataMap) {
        //表数据
        log.error("图片信息持久化开始");
        Connection connection = null;
        PreparedStatement pre = null;
        try {
            String wjl = MapUtils.getObjectIgnoreCase(tableDataMap, "WJL") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "WJL"));
            String kqdm = MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM"));
            String zhgxsj = MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ"));
            String wjlx = MapUtils.getObjectIgnoreCase(tableDataMap, "WJLX") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "WJLX"));
            String wjmc = MapUtils.getObjectIgnoreCase(tableDataMap, "WJMC") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "WJMC"));
            if (StringUtils.isNotBlank(wjl) && StringUtils.isNotBlank(kqdm) && StringUtils.isNotBlank(zhgxsj)) {
                // 保存图片到服务器
                String filePathAndName = saveWjxxjkFile(wjl, kqdm, zhgxsj, wjlx, wjmc);
                String sql = "update ODS_UP_WJXXJK set KQDM = ?,WJMC = ?,WJLX = ?,WJL = ?,ZHGXSJ = ?,CZBZ = ?,IS_UPLOAD = 0 where ID = ?";
                connection = dataSource.getConnection();
                pre = connection.prepareStatement(sql);
                //表数据
                pre.setString(1, kqdm);
                pre.setString(2, wjmc);
                pre.setString(3, wjlx);
                pre.setString(4, filePathAndName);
                pre.setString(5, zhgxsj);
                pre.setString(6, MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ")));
                pre.setString(7, MapUtils.getObjectIgnoreCase(tableDataMap, "ID") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ID")));
                pre.addBatch();
                pre.executeBatch();
                connection.commit();
                log.error("文件信息持久化结束");
            }
        } catch (Exception e) {
            if (connection != null) {
                try {
                    connection.rollback();
                } catch (Exception e1) {
                    throw new RuntimeException(e1.getMessage());
                }
            }
            throw new RuntimeException(e.getMessage());
        } finally {
            if (pre != null) {
                try {
                    pre.close();
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                } finally {
                    if (connection != null) {
                        try {
                            connection.close();
                        } catch (Exception e) {
                            throw new RuntimeException(e.getMessage());
                        }
                    }
                }
            }
        }
    }

    // 温湿度上传
    private void wsdInsert(Map tableDataMap) {
        //表数据
        log.error("温湿度信息持久化开始");
        Connection connection = null;
        PreparedStatement pre = null;
        try {
            connection = dataSource.getConnection();
            String sql = "insert into ODS_UP_WSDJCXXJK (WSDJCDH, JCSJ, HWDM, CFWW, CFWS, CFNW, CFNS, LSZGW, LSZDW, LSPJW, LSWDZJH, LSSDZJH, CZBZ, ZHGXSJ, ID, IS_UPLOAD) values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,0)";
            pre = connection.prepareStatement(sql);
            //表数据
            pre.setString(1, MapUtils.getObjectIgnoreCase(tableDataMap, "WSDJCDH") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "WSDJCDH")));
            pre.setString(2, MapUtils.getObjectIgnoreCase(tableDataMap, "JCSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "JCSJ")));
            pre.setString(3, MapUtils.getObjectIgnoreCase(tableDataMap, "HWDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "HWDM")));
            pre.setDouble(4, MapUtils.getObjectIgnoreCase(tableDataMap, "CFWW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFWW").toString()));
            pre.setDouble(5, MapUtils.getObjectIgnoreCase(tableDataMap, "CFWS") == null ? -1 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFWS").toString()));
            pre.setDouble(6, MapUtils.getObjectIgnoreCase(tableDataMap, "CFNW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFNW").toString()));
            pre.setDouble(7, MapUtils.getObjectIgnoreCase(tableDataMap, "CFNS") == null ? -1 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFNS").toString()));
            pre.setDouble(8, MapUtils.getObjectIgnoreCase(tableDataMap, "LSZGW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSZGW").toString()));
            pre.setDouble(9, MapUtils.getObjectIgnoreCase(tableDataMap, "LSZDW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSZDW").toString()));
            pre.setDouble(10, MapUtils.getObjectIgnoreCase(tableDataMap, "LSPJW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSPJW").toString()));
            pre.setString(11, MapUtils.getObjectIgnoreCase(tableDataMap, "LSWDZJH") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSWDZJH")));
            pre.setString(12, MapUtils.getObjectIgnoreCase(tableDataMap, "LSSDZJH") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSSDZJH")));
            pre.setString(13, MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ")));
            pre.setString(14, MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ")));
            pre.setString(15, String.valueOf(IdWorker.nextId()));
            pre.addBatch();
            pre.executeBatch();
            connection.commit();
            log.error("温湿度信息持久化结束");
        } catch (Exception e) {
            if (connection != null) {
                try {
                    connection.rollback();
                } catch (Exception e1) {
                    throw new RuntimeException(e1.getMessage());
                }
            }
            throw new RuntimeException(e.getMessage());
        } finally {
            if (pre != null) {
                try {
                    pre.close();
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                } finally {
                    if (connection != null) {
                        try {
                            connection.close();
                        } catch (Exception e) {
                            throw new RuntimeException(e.getMessage());
                        }
                    }
                }
            }
        }
    }

    // 文件上传
    private void wsdUpdate(Map tableDataMap) {
        //表数据
        log.error("温湿度信息持久化开始");
        Connection connection = null;
        PreparedStatement pre = null;
        try {
            connection = dataSource.getConnection();
            String sql = "update ODS_UP_WSDJCXXJK set WSDJCDH = ?, JCSJ = ?, HWDM = ?, CFWW = ?, CFWS = ?, CFNW = ?, CFNS = ?, LSZGW = ?, LSZDW = ?, LSPJW = ?, LSWDZJH = ?, LSSDZJH = ?, CZBZ = ?, ZHGXSJ = ?, IS_UPLOAD = 0 where ID = ?";
            pre = connection.prepareStatement(sql);
            //表数据
            pre.setString(1, MapUtils.getObjectIgnoreCase(tableDataMap, "WSDJCDH") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "WSDJCDH")));
            pre.setString(2, MapUtils.getObjectIgnoreCase(tableDataMap, "JCSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "JCSJ")));
            pre.setString(3, MapUtils.getObjectIgnoreCase(tableDataMap, "HWDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "HWDM")));
            pre.setDouble(4, MapUtils.getObjectIgnoreCase(tableDataMap, "CFWW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFWW").toString()));
            pre.setDouble(5, MapUtils.getObjectIgnoreCase(tableDataMap, "CFWS") == null ? -1 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFWS").toString()));
            pre.setDouble(6, MapUtils.getObjectIgnoreCase(tableDataMap, "CFNW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFNW").toString()));
            pre.setDouble(7, MapUtils.getObjectIgnoreCase(tableDataMap, "CFNS") == null ? -1 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFNS").toString()));
            pre.setDouble(8, MapUtils.getObjectIgnoreCase(tableDataMap, "LSZGW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSZGW").toString()));
            pre.setDouble(9, MapUtils.getObjectIgnoreCase(tableDataMap, "LSZDW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSZDW").toString()));
            pre.setDouble(10, MapUtils.getObjectIgnoreCase(tableDataMap, "LSPJW") == null ? -100 : Double.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSPJW").toString()));
            pre.setString(11, MapUtils.getObjectIgnoreCase(tableDataMap, "LSWDZJH") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSWDZJH")));
            pre.setString(12, MapUtils.getObjectIgnoreCase(tableDataMap, "LSSDZJH") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "LSSDZJH")));
            pre.setString(13, MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ")));
            pre.setString(14, MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ")));
            pre.setString(15, MapUtils.getObjectIgnoreCase(tableDataMap, "ID") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ID")));
            pre.addBatch();
            pre.executeBatch();
            connection.commit();
            log.error("温湿度信息持久化结束");
        } catch (Exception e) {
            if (connection != null) {
                try {
                    connection.rollback();
                } catch (Exception e1) {
                    throw new RuntimeException(e1.getMessage());
                }
            }
            throw new RuntimeException(e.getMessage());
        } finally {
            if (pre != null) {
                try {
                    pre.close();
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                } finally {
                    if (connection != null) {
                        try {
                            connection.close();
                        } catch (Exception e) {
                            throw new RuntimeException(e.getMessage());
                        }
                    }
                }
            }
        }
    }


    private void cnsptxInsert(Map tableDataMap) {
        //表数据
        log.error("仓内视频图像持久化开始");
        Connection connection = null;
        PreparedStatement pre = null;
        try {
            String kqdm = MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM"));
            String cfdm = MapUtils.getObjectIgnoreCase(tableDataMap, "CFDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFDM"));
            String hwdm = MapUtils.getObjectIgnoreCase(tableDataMap, "HWDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "HWDM"));
            String zhgxsj = MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ"));
            String cntxwjl = MapUtils.getObjectIgnoreCase(tableDataMap, "CNTXWJL") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CNTXWJL"));
            String txwjhzm = MapUtils.getObjectIgnoreCase(tableDataMap, "TXWJHZM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "TXWJHZM"));
            String zpsj = MapUtils.getObjectIgnoreCase(tableDataMap, "ZPSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZPSJ"));
            if (StringUtils.isNotBlank(cntxwjl) && StringUtils.isNotBlank(kqdm) &&
                    StringUtils.isNotBlank(zpsj) && StringUtils.isNotBlank(cfdm) &&
                    StringUtils.isNotBlank(hwdm) && StringUtils.isNotBlank(txwjhzm)) {
                // 保存图片到服务器
                String filePathAndName = saveCnsptxxxjkFile(cntxwjl, kqdm, zpsj, cfdm, hwdm, txwjhzm);
                String sql = "insert into ODS_UP_CNSPTXXXJK (KQDM, CFDM, HWDM, SPJKSBID, ZPSJ, CNTXWJL, TXWJHZM, YZWBH, CZBZ, ZHGXSJ, IS_UPLOAD, ID) values (?,?,?,?,?,?,?,?,?,?,0,?)";
                connection = dataSource.getConnection();
                pre = connection.prepareStatement(sql);
                //表数据
                pre.setString(1, kqdm);
                pre.setString(2, cfdm);
                pre.setString(3, hwdm);
                pre.setString(4, MapUtils.getObjectIgnoreCase(tableDataMap, "SPJKSBID") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "SPJKSBID")));
                pre.setString(5, zpsj);
                pre.setString(6, filePathAndName);
                pre.setString(7, txwjhzm);
                pre.setString(8, MapUtils.getObjectIgnoreCase(tableDataMap, "YZWBH") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "YZWBH")));
                pre.setString(9, MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ")));
                pre.setString(10, zhgxsj);
                pre.setString(11, String.valueOf(IdWorker.nextId()));
                pre.addBatch();
                pre.executeBatch();
                connection.commit();
                log.error("仓内视频图像持久化结束");
            }
        } catch (Exception e) {
            if (connection != null) {
                try {
                    connection.rollback();
                } catch (Exception e1) {
                    throw new RuntimeException(e1.getMessage());
                }
            }
            throw new RuntimeException(e.getMessage());
        } finally {
            if (pre != null) {
                try {
                    pre.close();
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                } finally {
                    if (connection != null) {
                        try {
                            connection.close();
                        } catch (Exception e) {
                            throw new RuntimeException(e.getMessage());
                        }
                    }
                }
            }
        }
    }


    private void cnsptxUpdate(Map tableDataMap) {
        //表数据
        log.error("仓内视频图像持久化开始");
        Connection connection = null;
        PreparedStatement pre = null;
        try {
            String kqdm = MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM"));
            String cfdm = MapUtils.getObjectIgnoreCase(tableDataMap, "CFDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CFDM"));
            String hwdm = MapUtils.getObjectIgnoreCase(tableDataMap, "HWDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "HWDM"));
            String zhgxsj = MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ"));
            String cntxwjl = MapUtils.getObjectIgnoreCase(tableDataMap, "CNTXWJL") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CNTXWJL"));
            String txwjhzm = MapUtils.getObjectIgnoreCase(tableDataMap, "TXWJHZM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "TXWJHZM"));
            String zpsj = MapUtils.getObjectIgnoreCase(tableDataMap, "ZPSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZPSJ"));
            if (StringUtils.isNotBlank(cntxwjl) && StringUtils.isNotBlank(kqdm) &&
                    StringUtils.isNotBlank(zpsj) && StringUtils.isNotBlank(cfdm) &&
                    StringUtils.isNotBlank(hwdm) && StringUtils.isNotBlank(txwjhzm)) {
                // 保存图片到服务器
                String filePathAndName = saveCnsptxxxjkFile(cntxwjl, kqdm, zpsj, cfdm, hwdm, txwjhzm);
                String sql = "update ODS_UP_CNSPTXXXJK set KQDM = ?, CFDM = ?, HWDM = ?, SPJKSBID = ?, ZPSJ = ?, CNTXWJL = ?, TXWJHZM = ?, YZWBH = ?, CZBZ = ?, ZHGXSJ = ?,IS_UPLOAD = 0 where ID = ?";
                connection = dataSource.getConnection();
                pre = connection.prepareStatement(sql);
                //表数据
                pre.setString(1, kqdm);
                pre.setString(2, cfdm);
                pre.setString(3, hwdm);
                pre.setString(4, MapUtils.getObjectIgnoreCase(tableDataMap, "SPJKSBID") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "SPJKSBID")));
                pre.setString(5, zpsj);
                pre.setString(6, filePathAndName);
                pre.setString(7, txwjhzm);
                pre.setString(8, MapUtils.getObjectIgnoreCase(tableDataMap, "YZWBH") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "YZWBH")));
                pre.setString(9, MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ")));
                pre.setString(10, zhgxsj);
                pre.setString(11, MapUtils.getObjectIgnoreCase(tableDataMap, "ID") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ID")));
                pre.addBatch();
                pre.executeBatch();
                connection.commit();
                log.error("仓内视频图像持久化结束");
            }
        } catch (Exception e) {
            if (connection != null) {
                try {
                    connection.rollback();
                } catch (Exception e1) {
                    throw new RuntimeException(e1.getMessage());
                }
            }
            throw new RuntimeException(e.getMessage());
        } finally {
            if (pre != null) {
                try {
                    pre.close();
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                } finally {
                    if (connection != null) {
                        try {
                            connection.close();
                        } catch (Exception e) {
                            throw new RuntimeException(e.getMessage());
                        }
                    }
                }
            }
        }
    }

    private void spjkycsjgjInsert(Map tableDataMap) {
        //表数据
        log.error("视频监控异常事件告警信息持久化开始");
        Connection connection = null;
        PreparedStatement pre = null;
        try {
            String gjsj = MapUtils.getObjectIgnoreCase(tableDataMap, "GJSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "GJSJ"));
            String kqdm = MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM"));
            String spwjhzm = MapUtils.getObjectIgnoreCase(tableDataMap, "SPWJHZM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "SPWJHZM"));
            String spwjl = MapUtils.getObjectIgnoreCase(tableDataMap, "SPWJL") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "SPWJL"));
            String spjksbId = MapUtils.getObjectIgnoreCase(tableDataMap, "SPJKSBID") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "SPJKSBID"));
            if (StringUtils.isNotBlank(gjsj) && StringUtils.isNotBlank(kqdm) &&
                    StringUtils.isNotBlank(spwjhzm) && StringUtils.isNotBlank(spwjl) &&
                    StringUtils.isNotBlank(spjksbId)) {
                // 保存图片到服务器
                String filePathAndName = saveSpjkycsjgjjbxxjkFile(spwjl, kqdm, gjsj, spjksbId, spwjhzm);
                String sql = "insert into ODS_UP_SPJKYCSJGJJBXXJK (GJSJ, KQMC, KQDM, KQDZ, SPJKSBID, AZWZLX, JSQYSM, YCGJSM, CZBZ, ZHGXSJ, ID, IS_UPLOAD, SPWJL, SPWJHZM) values (?,?,?,?,?,?,?,?,?,?,?,0,?,?)";
                connection = dataSource.getConnection();
                pre = connection.prepareStatement(sql);
                //表数据
                pre.setString(1, gjsj);
                pre.setString(2, MapUtils.getObjectIgnoreCase(tableDataMap, "KQMC") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQMC")));
                pre.setString(3, kqdm);
                pre.setString(4, MapUtils.getObjectIgnoreCase(tableDataMap, "KQDZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQDZ")));
                pre.setString(5, spjksbId);
                pre.setString(6, MapUtils.getObjectIgnoreCase(tableDataMap, "AZWZLX") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "AZWZLX")));
                pre.setString(7, MapUtils.getObjectIgnoreCase(tableDataMap, "JSQYSM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "JSQYSM")));
                pre.setString(8, MapUtils.getObjectIgnoreCase(tableDataMap, "YCGJSM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "YCGJSM")));
                pre.setString(9, MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ")));
                pre.setString(10, MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ")));
                pre.setString(11, String.valueOf(IdWorker.nextId()));
                pre.setString(12, filePathAndName);
                pre.setString(13, spwjhzm);
                pre.addBatch();
                pre.executeBatch();
                connection.commit();
                log.error("视频监控异常事件告警信息持久化结束");
            }
        } catch (Exception e) {
            if (connection != null) {
                try {
                    connection.rollback();
                } catch (Exception e1) {
                    throw new RuntimeException(e1.getMessage());
                }
            }
            throw new RuntimeException(e.getMessage());
        } finally {
            if (pre != null) {
                try {
                    pre.close();
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                } finally {
                    if (connection != null) {
                        try {
                            connection.close();
                        } catch (Exception e) {
                            throw new RuntimeException(e.getMessage());
                        }
                    }
                }
            }
        }
    }


    // 文件上传
    private void spjkycsjgjUpdate(Map tableDataMap) {
        //表数据
        log.error("视频监控异常事件告警信息持久化开始");
        Connection connection = null;
        PreparedStatement pre = null;
        try {
            String gjsj = MapUtils.getObjectIgnoreCase(tableDataMap, "GJSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "GJSJ"));
            String kqdm = MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQDM"));
            String spwjhzm = MapUtils.getObjectIgnoreCase(tableDataMap, "SPWJHZM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "SPWJHZM"));
            String spwjl = MapUtils.getObjectIgnoreCase(tableDataMap, "SPWJL") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "SPWJL"));
            String spjksbId = MapUtils.getObjectIgnoreCase(tableDataMap, "SPJKSBID") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "SPJKSBID"));
            if (StringUtils.isNotBlank(gjsj) && StringUtils.isNotBlank(kqdm) &&
                    StringUtils.isNotBlank(spwjhzm) && StringUtils.isNotBlank(spwjl) &&
                    StringUtils.isNotBlank(spjksbId)) {
                // 保存图片到服务器
                String filePathAndName = saveSpjkycsjgjjbxxjkFile(spwjl, kqdm, gjsj, spjksbId, spwjhzm);
                String sql = "update ODS_UP_SPJKYCSJGJJBXXJK set GJSJ = ?, KQMC = ?, KQDM = ?, KQDZ = ?, SPJKSBID = ?, AZWZLX = ?," +
                        " JSQYSM = ?, YCGJSM = ?, CZBZ = ?, ZHGXSJ = ?, IS_UPLOAD = 0, SPWJL = ?, SPWJHZM = ? where ID = ?";
                connection = dataSource.getConnection();
                pre = connection.prepareStatement(sql);
                //表数据
                pre.setString(1, gjsj);
                pre.setString(2, MapUtils.getObjectIgnoreCase(tableDataMap, "KQMC") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQMC")));
                pre.setString(3, kqdm);
                pre.setString(4, MapUtils.getObjectIgnoreCase(tableDataMap, "KQDZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "KQDZ")));
                pre.setString(5, spjksbId);
                pre.setString(6, MapUtils.getObjectIgnoreCase(tableDataMap, "AZWZLX") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "AZWZLX")));
                pre.setString(7, MapUtils.getObjectIgnoreCase(tableDataMap, "JSQYSM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "JSQYSM")));
                pre.setString(8, MapUtils.getObjectIgnoreCase(tableDataMap, "YCGJSM") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "YCGJSM")));
                pre.setString(9, MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "CZBZ")));
                pre.setString(10, MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ZHGXSJ")));
                pre.setString(11, filePathAndName);
                pre.setString(12, spwjhzm);
                pre.setString(13, MapUtils.getObjectIgnoreCase(tableDataMap, "ID") == null ? "" : String.valueOf(MapUtils.getObjectIgnoreCase(tableDataMap, "ID")));
                pre.addBatch();
                pre.executeBatch();
                connection.commit();
                log.error("视频监控异常事件告警信息持久化结束");
            }
        } catch (Exception e) {
            if (connection != null) {
                try {
                    connection.rollback();
                } catch (Exception e1) {
                    throw new RuntimeException(e1.getMessage());
                }
            }
            throw new RuntimeException(e.getMessage());
        } finally {
            if (pre != null) {
                try {
                    pre.close();
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                } finally {
                    if (connection != null) {
                        try {
                            connection.close();
                        } catch (Exception e) {
                            throw new RuntimeException(e.getMessage());
                        }
                    }
                }
            }
        }
    }

    /**
     * 文件信息
     */
    private String saveWjxxjkFile(String wjl, String kqdm, String zhgxsj, String wjlx, String wjmc) {
        // 组装路径 kqdm/data/wjxxjk/wjlx
        String filePath = kqdm + File.separator + zhgxsj.trim().substring(0, 10) + File.separator +
                "wjxxjk" + File.separator + wjlx;
        return saveFile(wjl, filePath, wjmc);
    }

    /**
     * 仓内视频图像
     */
    private String saveCnsptxxxjkFile(String wjl, String kqdm, String zpsj, String cfdm, String hwdm, String txwjhzm) {
        // 组装路径 kqdm/data/cnsptxxxjk/cfdm
        String filePath = kqdm + File.separator + zpsj.trim().substring(0, 10) + File.separator +
                "cnsptxxxjk" + File.separator + cfdm;
        SplittableRandom splittableRandom = new SplittableRandom();
        int random = splittableRandom.nextInt(0, 1000);
        String fileName = hwdm + random + "." + txwjhzm;
        return saveFile(wjl, filePath, fileName);
    }

    /**
     * 视频监控异常事件告警
     */
    private String saveSpjkycsjgjjbxxjkFile(String wjl, String kqdm, String gjsj, String spjksbId, String spwjhzm) {
        // 组装路径 kqdm/data/spjkycsjgjjbxxjk/spjksbid
        String filePath = kqdm + File.separator + gjsj.trim().substring(0, 10) + File.separator +
                "spjkycsjgjjbxxjk" + File.separator + spjksbId;
        SplittableRandom splittableRandom = new SplittableRandom();
        int random = splittableRandom.nextInt(0, 10000);
        String fileName = random + "." + spwjhzm;
        return saveFile(wjl, filePath, fileName);
    }

    public String saveFile(String wjl, String filePath, String fileName) {
        FileUtil.saveFile(wjl, baseFilePath + File.separator + filePath, fileName);
        return filePath + File.separator + fileName;
    }


}
