package com.unis.hlht.cjlksj.server.server;

import com.alibaba.fastjson.JSON;
import com.unis.hlht.cjlksj.server.common.data.LiangKuConfig;
import com.unis.hlht.cjlksj.server.dto.datashare.DataShareConfig;
import com.unis.hlht.cjlksj.server.dto.datashare.DataShareReqDTO;
import com.unis.hlht.cjlksj.server.dto.datashare.DataShareRespDTO;
import com.unis.hlht.cjlksj.server.entity.TableCommentEntity;
import com.unis.hlht.cjlksj.server.mapper.DataShareMapper;
import com.unis.hlht.cjlksj.server.mapper.TableCommentMapper;
import com.unis.hlht.cjlksj.server.utils.DateUtil;
import com.unis.hlht.cjlksj.server.utils.RSAUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import java.util.List;
import java.util.Map;

@Slf4j
@Service
@SuppressWarnings("all")
public class DataShareServer {

    @Autowired
    private DataShareMapper dataShareMapper;

    @Autowired
    private LiangKuConfig liangKuConfig;

    @Autowired
    private RestTemplate restTemplate;

    @Autowired
    private TableCommentMapper tableCommentMapper;

    /**
     * 市级下载数据
     *
     * @param api
     * @param dto
     * @return
     */
    public DataShareRespDTO download(String api, DataShareReqDTO dto) {
        DataShareRespDTO resdto = new DataShareRespDTO();

        String access_token = dto.getAccess_token();
        String userid = dto.getUserid();

        DataShareRespDTO infoVerify = notNullVerify(api, userid, access_token, resdto);
        if (infoVerify != null) {
            return infoVerify;
        }

        // 定义变量
        Integer pointer = dto.getPointer();
        List<String> tyshxydmList = DataShareConfig.getTyshxydmList(userid);
        Integer pageIndex, nextpointer, pageSize = 100;
        String isTransmitComplete = "0";
        pageIndex = pointer;


        List<Map> data = dataShareMapper.findByTableName(api, tyshxydmList, pageIndex, pageIndex + pageSize);
        // 数据总量
        Long dataCount = dataShareMapper.findCountByTableName(api, tyshxydmList);
        int size = data.size();
        nextpointer = pointer + size;
        if (nextpointer.equals(dataCount.intValue())) {
            isTransmitComplete = "1";
        }

        // 主体数据加密
        try {
//			String bodyStr = SecureMngr.encrypt(JSON.toJSONString(data), liangKuConfig.getPassword());
            String bodyStr = RSAUtil.encryptByPubKey(JSON.toJSONString(data), DataShareConfig.shengji_pub_key);
            resdto.setData(bodyStr);
            resdto.setIsTransmitComplete(isTransmitComplete);
            resdto.setNextpointer(nextpointer);
            resdto.setRetcode("200");
            resdto.setRetMsg("数据处理成功");
            log.info("数据处理完成，数据总量=" + size);
        } catch (Exception e) {
//			e.printStackTrace();
            resdto.setRetcode("500");
            resdto.setRetMsg("数据处理异常！");
        }
        return resdto;
    }

    /**
     * 入参信息验证
     *
     * @param api
     * @param userid
     * @param access_token
     * @param resdto
     * @return
     */
    private DataShareRespDTO notNullVerify(String api, String userid, String access_token, DataShareRespDTO resdto) {
        // 判断表名 是否为空
        if (api != null) {
            api = api.trim();
        } else {
            resdto.setRetcode("500");
            resdto.setRetMsg("api不能为空！");
            return resdto;
        }

        // 判断userid 是否为空
        if (userid != null) {
            userid = userid.trim();
        } else {
            resdto.setRetcode("500");
            resdto.setRetMsg("userid不能为空！");
            return resdto;
        }

        // 判断access_token 是否为空
        if (access_token != null) {
            access_token = access_token.trim();
        } else {
            resdto.setRetcode("500");
            resdto.setRetMsg("access_token不能为空！");
            return resdto;
        }

        // 验证身份
        String pubKey = DataShareConfig.getPubKey(userid);
        try {
            boolean verify = RSAUtil.verify(getSourceAccessToken(userid), access_token, pubKey);
            if (verify == false) {
                resdto.setRetcode("40102");
                resdto.setRetMsg("数据验签失败");
                return resdto;
            }
        } catch (Exception e1) {
            resdto.setRetcode("500");
            resdto.setRetMsg("签名验证异常");
//			e1.printStackTrace();
            return resdto;
        }
        return null;
    }


    /**
     * 获取身份签名源字符串
     *
     * @return
     */
    private String getSourceAccessToken(String uid) throws Exception {
        // 对身份信息进行本地私钥签名
        String accessToken = uid + "_" + DateUtil.getNowDateFormat("yyyy-MM-dd");
        return accessToken;
    }

    private static String getSourceAccessTokenTmp(String uid) throws Exception {
        // 对身份信息进行本地私钥签名
        String accessToken = uid + "_" + DateUtil.getNowDateFormat("yyyy-MM-dd");
        String sign = RSAUtil.sign(accessToken, DataShareConfig.getPubKey(uid));
        System.out.println(accessToken);
        System.out.println(sign);
        return accessToken;
    }


    public String getDataCount(String userId) {
        List<String> tyshxydmList = DataShareConfig.getTyshxydmList(userId);
        List<TableCommentEntity> all = tableCommentMapper.findAllTable();
        StringBuffer sb = new StringBuffer();
        for (TableCommentEntity t : all) {
            // 数据总量
            String tName = t.getTABLE_NAME();
            Long dataCount = dataShareMapper.findCountByTableName(tName, tyshxydmList);
            System.out.println("表名：" + tName + ",数据量：" + dataCount);
            sb.append("表名：");
            sb.append(tName);
            sb.append("--->表名：");
            sb.append("数据量：");
            sb.append(dataCount);
            sb.append("\n");
        }
        return sb.toString();
    }
}
