package com.unis.hlht.cjlksj.server.server;

import com.unis.hlht.cjlksj.server.dto.datashow.RegexDataDTO;
import com.unis.hlht.cjlksj.server.mapper.GrabResultMapper;
import com.unis.hlht.cjlksj.server.mapper.RegexDataMapper;
import com.unis.hlht.cjlksj.server.utils.ClobUtils;
import com.unis.hlht.cjlksj.server.utils.DateUtil;
import lombok.extern.log4j.Log4j2;
import org.apache.ibatis.jdbc.SQL;
import org.dom4j.DocumentException;
import org.dom4j.Element;
import org.dom4j.Node;
import org.dom4j.io.SAXReader;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Log4j2
@Service
public class RegexDataserver {

    @Autowired
    private GrabResultMapper regexMapper;

    @Autowired
    private RegexDataMapper regexDataMapper;

    /*
    根据文件名查询所有表
     */
    public List<Map> getTableElesByFileName() {
        String fileName = "config/shanxi_shengdu.xml";
        // 加载数据校验规则
        org.dom4j.Document document = getDom(DataUpLoadServer.class.getClassLoader().getResourceAsStream(fileName));
        Element root = document.getRootElement();
        //获取所有数据表
        List<Map> tableEles = root.selectNodes("/tables/table");
        return tableEles;
    }

    /*
    查询单个表
     */
    public Element getTableEle(String queryTableName) {
        List<Map> tableEles = getTableElesByFileName();
        Element element = null;
        if (tableEles.size() > 0) {
            for (int i = 0; i < tableEles.size(); i++) {
                Element ele = (Element) tableEles.get(i);
                String tableName = ele.attributeValue("name");
                if (queryTableName.equals(tableName)) {
                    element = ele;
                }
            }
        }
        return element;
    }

    /*
    获取所有数据校验问题
     */
    public List<Map> getErrorListByTableID(String queryTableName, String TableID) {
//        generalMapper.getByLogickey();

        List<Map> errorlist = new ArrayList<>();
        Element ele = getTableEle(queryTableName);
        if (ele != null) {
            String tableName = ele.attributeValue("name");
            List<Node> columnList = ele.selectNodes("column[@sql|@remark]");
            if (columnList != null && columnList.size() > 0) {
                for (int i = 0; i < columnList.size(); i++) {
                    Element columnEle = (Element) columnList.get(i);
                    String columnname = columnEle.getTextTrim().toUpperCase();
                    String sql = columnEle.attributeValue("sql");
                    String remark = columnEle.attributeValue("remark");
                    List<Map> list = regexMapper.select(sql);
                    for (Map map : list) {
                        String info = map.get("QYXX") + "";
                        String errorColumn = map.get("ERRORCOLUMN") + "";
                        String ID = map.get("ID").toString();
                        Map<String, String> vM = new HashMap<String, String>();
                        if (ID.equals(TableID)) {
                            vM.put("ID", ID);
                            vM.put("TNAME", tableName);
                            vM.put("KDMC", info);
                            vM.put("INFO", columnname + ":" + remark);
                            vM.put("VAL", errorColumn);
                            vM.put("NAME", columnname);
                            if (errorlist.contains(vM) == false) {
                                errorlist.add(vM);
                            }
                        }
                    }
                }
            }
        }
        return errorlist;
    }

    public void UpdateByTableId(RegexDataDTO regexDataDTO) {
        String tableName = regexDataDTO.getTableName();
        String id = regexDataDTO.getID();
        Map tableDataMap = regexDataDTO.getTableDataMap();
        List<Map> cList = getZDBMListByTableName(tableName);
        String updateSql = getUpdateSql(cList, id, tableName, tableDataMap);
        regexDataMapper.UpdateByTableId(updateSql);
//        StringBuffer sql1 = new StringBuffer();
//        sql1.append("UPDATE " + tableName + " SET ");
//        StringBuffer values = new StringBuffer();
//        for (int i = 0; i < cList.size(); i++) {
//            Map map = cList.get(i);
//            String zdbm = map.get("ZDBM").toString();
//            if (tableDataMap.containsKey(zdbm)) {
//                if (tableDataMap.get(zdbm) != null) {
//                    values.append(zdbm + " = '" + tableDataMap.get(zdbm) + "',");
//                }
//            }
//        }
//        sql1.append(values.substring(0, values.lastIndexOf(",")));
//        if(!tableDataMap.containsKey("CZBZ")){
//            sql1.append(" ,CZBZ = 'u' ");
//        }
//        sql1.append(" WHERE id = '" + id + "' and CZBZ in ('i','u')");
//        sql1.append(" and ZHGXSJ = to_date('" + DateUtil.getDateTime() + "','YYYY-MM-DD HH24:MI:SS')");
//        regexDataMapper.UpdateByTableId(sql1.toString());

    }


    public String getUpdateSql(List<Map> columnList, String ID, String tableName, Map tableDataMap) {
        SQL sql = new SQL();
        sql.UPDATE(tableName);
        for (int i = 0; i < columnList.size(); i++) {
            Map map = columnList.get(i);
            Object column = map.get("ZDBM");
            if (tableDataMap.containsKey(column)) {
                Object columbValue = tableDataMap.get(column);
                if (column.equals("id") == false) {
                    if (column.toString().equalsIgnoreCase("czbz")) {
                        sql.SET(column + "=" + "'u'");
                    } else if (columbValue instanceof Integer || columbValue instanceof Long || columbValue instanceof Double
                            || columbValue instanceof Float || columbValue instanceof Boolean) {
                        sql.SET(column + "=" + columbValue);
                    } else if (ClobUtils.isClob(tableDataMap.get("tableName") + "", column.toString())) {
                        sql.SET(column + "=#{" + column + ",jdbcType=CLOB}");
                    } else {
                        sql.SET(column + "= '" + columbValue + "'");
                    }
                }
            }
        }
        sql.SET("is_upload = 0");
        sql.SET("ZHGXSJ ='" + DateUtil.getDateTime2() + "'");
        sql.WHERE("id = '" + ID + "'");
        return sql.toString();
    }

    public List<Map> getZDBMListByTableName(String tableName) {
        String zdbmSql = "select ZDBM " +
                "from sys_datadict  " +
                "where zd_f_bm = '" + tableName + "'" +
                " and IS_SHOW = 1 ";
        List<Map> cList = regexDataMapper.select(zdbmSql);
        return cList;
    }

    public static org.dom4j.Document getDom(InputStream in) {
        org.dom4j.Document document = null;
        SAXReader saxReader = null;
        saxReader = new SAXReader();
        if (in != null) {
            try {
                document = saxReader.read(in);
            } catch (DocumentException e) {
                e.printStackTrace();
            }
        }
        return document;
    }
}
