package com.unis.hlht.cjlksj.server.server.haikang;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hikvision.artemis.sdk.ArtemisHttpUtil;
import com.hikvision.artemis.sdk.config.ArtemisConfig;
import com.unis.hlht.cjlksj.server.entity.HKSBXX;
import com.unis.hlht.cjlksj.server.entity.HKZZJG;
import com.unis.hlht.cjlksj.server.mapper.HKSBXXMapper;
import com.unis.hlht.cjlksj.server.mapper.HKZZJGMapper;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;


@Log4j2
@Service
@SuppressWarnings("all")
public class HaikangServer {

    // artemis网关服务器ip端口
    private static final String host = "192.168.11.101:443";
    // 秘钥appkey
    private static final String appKey = "29700766";
    // 秘钥appSecret
    private static final String appSecret = "O7puROlUW8MGhu0FdaY8";

    // 设置海康sdk参数
    static {
        ArtemisConfig.host = host;
        ArtemisConfig.appKey = appKey;
        ArtemisConfig.appSecret = appSecret;
    }

    private static final String ARTEMIS_PATH = "/artemis";

    @Autowired
    private HKZZJGMapper hkzzjgMapper;

    @Autowired
    private HKSBXXMapper hksbxxMapper;

    /**
     * 同步海康组织机构信息
     */
    public void synHkZzjg() {
        try {
            String resultData = getHkZzjgOfPage(1, 1000);
            // 将String转化为json数据
            JSONObject objData = JSONObject.parseObject(resultData);
            JSONObject jsonObjData = objData.getJSONObject("data");
            JSONArray arrayList = JSON.parseArray(jsonObjData.getString("list"));
            Iterator<Object> it = arrayList.iterator();
            while (it.hasNext()) {
                JSONObject obj = (JSONObject) it.next();
                HKZZJG hkzzjg = JSONObject.parseObject(obj.toString(), HKZZJG.class);
                String indexCode = hkzzjg.getIndexCode();
                hkzzjg.setID(indexCode);
                Integer count = hkzzjgMapper.count(indexCode);
                if (count != null && count > 0) {
                    hkzzjgMapper.delete(indexCode);
                }
                hkzzjgMapper.save(hkzzjg);
            }
        } catch (Exception e) {
            log.error("同步海康组织机构错误", e);
        }
    }

    /**
     * 通过海康openApi获取组织机构信息
     *
     * @param pageNo
     * @param pageSize
     * @return
     */
    private String getHkZzjgOfPage(Integer pageNo, Integer pageSize) {
        String body = null;
        String contentType = null;
        Map path = new HashMap();
        // 设置接口的URI地址= OpenAPI接口的上下文 + uri
        // 获取区域列表
        final String hkApi = ARTEMIS_PATH + "/api/irds/v2/region/nodesByParams";
        path = new HashMap(2) {
            {
                // 根据现场环境部署确认是http还是https
                put("https://", hkApi);
            }
        };
        // 设置参数提交方式
        contentType = "application/json";
        // 组装请求参数
        JSONObject jsonBody = new JSONObject();
        // 获取区域列表所要传的参数
        jsonBody.put("pageNo", pageNo);
        jsonBody.put("pageSize", pageSize);
        jsonBody.put("resourceType", "camera");
        jsonBody.put("cascadeFlag", 0);
        body = jsonBody.toJSONString();
        // 调用接口: post请求application/json类型参数
        String result = ArtemisHttpUtil.doPostStringArtemis(path, body, null, null, contentType, null);
        return result;
    }


    /**
     * 同步海康设备信息
     */
    public void synHkSbxx() {
        try {
            Integer pageNo = 1;
            Integer pageSize = 1;
            String result = getHkSbxxOfPage(pageNo, pageSize);
            JSONObject jsonString = JSONObject.parseObject(result);
            JSONObject jsonData = jsonString.getJSONObject("data");
            // 总条数
            Integer jsonTotal = jsonData.getInteger("total");
            Integer pageCount = (int) Math.ceil(jsonTotal / 200f);
            String resultData = null;
            while (pageNo <= pageCount) {
                resultData = getHkSbxxOfPage(pageNo, 200);
                saveSbxx(resultData);
                pageNo++;
            }
        } catch (Exception e) {
            log.error("同步海康设备信息错误", e);
        }
    }

    /**
     * 通过海康openApi获取设备信息
     *
     * @param pageNo
     * @param pageSize
     * @return
     */
    private String getHkSbxxOfPage(Integer pageNo, Integer pageSize) {
        String body = null;
        String contentType = null;
        Map path = new HashMap();
        // 设置接口的URI地址= OpenAPI接口的上下文 + uri
        // 分页获取监控点资源
        final String hkApi = ARTEMIS_PATH + "/api/resource/v1/cameras";
        path = new HashMap(2) {
            {
                // 根据现场环境部署确认是http还是https
                put("https://", hkApi);
            }
        };
        // 设置参数提交方式
        contentType = "application/json";
        // 组装请求参数
        JSONObject jsonBody = new JSONObject();
        // 获取分页监控点资源参数
        jsonBody.put("pageNo", pageNo);
        jsonBody.put("pageSize", pageSize);
        body = jsonBody.toJSONString();
        // 调用接口: post请求application/json类型参数
        String result = ArtemisHttpUtil.doPostStringArtemis(path, body, null, null, contentType, null);
        return result;
    }

    /**
     * 保存海康设备信息
     *
     * @param resultData
     */
    private void saveSbxx(String resultData) {
        // 将String转化为json数据
        JSONObject objData = JSONObject.parseObject(resultData);
        JSONObject jsonObjData = objData.getJSONObject("data");
        JSONArray arrayList = JSON.parseArray(jsonObjData.getString("list"));
        Iterator<Object> it = arrayList.iterator();
        while (it.hasNext()) {
            JSONObject obj = (JSONObject) it.next();
            HKSBXX hksbxx = JSONObject.parseObject(obj.toString(), HKSBXX.class);
            String cameraIndexCode = hksbxx.getCameraIndexCode();
            hksbxx.setID(cameraIndexCode);
            Integer count = hksbxxMapper.count(cameraIndexCode);
            if (count != null && count > 0) {
                hksbxxMapper.delete(cameraIndexCode);
            }
            hksbxxMapper.save(hksbxx);
        }
    }

}
