package com.unis.hlht.cjlksj.server.utils;

import java.io.FileOutputStream;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFHyperlink;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.usermodel.Hyperlink;

public class RegexExcelUtil {
	
	/**
	 * 
	 * @param indexPageName		目录页sheet名称
	 * @param sheetColumn		取sheet列名称的字段名
	 * @param dataColumn		取sheet列数据的字段名
	 * @param title				所有sheet数据标题、这里中写的是统一列名若需要不同列名的需要自己扩展一下
	 * @param sheetMapList		每个sheet的数据｛sheet名称，content数据｝
	 * @return
	 * @throws IOException
	 */
	public static HSSFWorkbook createMutiSheet(String indexPageName, String sheetColumn, String dataColumn, String[] title,
			List<Map> sheetMapList) 
			throws IOException {
		/* 建立HSSFWorkbook对象 */
		HSSFWorkbook wb = new HSSFWorkbook();

		/* 建立索引页sheet */
		HSSFSheet sheet = wb.createSheet(indexPageName);
		
		int index = 0;
		for (Map<?, ?> sheetMap : sheetMapList) {
			
			
			//取出每个sheet的名称
			String sheetName = sheetMap.get(sheetColumn)+"";
			
			//取出每个sheet的数据 
			Object object = sheetMap.get(dataColumn);
			String[][] cotent = (String[][])object;
			
			//若自定义了title则不使用公共title
			Object titleObj = sheetMap.get("title");
			if(titleObj != null) {
				title = (String[])titleObj;
			}

			
			HSSFRow row = sheet.createRow((short) index);
			HSSFCell likeCell = row.createCell(0);
			Hyperlink hyperlink = new HSSFHyperlink(Hyperlink.LINK_DOCUMENT);
		
			// "#"表示本文档 "sheetName"表示sheet页名称 "A10"表示第几列第几行
			hyperlink.setAddress("#"+sheetName+"!A1");
			likeCell.setHyperlink(hyperlink);
			// 点击进行跳转
			likeCell.setCellValue(sheetName);
			
			/* 连接跳转 */
			/* 设置为超链接的样式 */
			HSSFCellStyle linkStyle = wb.createCellStyle();
			HSSFFont cellFont = wb.createFont();
			cellFont.setUnderline((byte) 1);
			cellFont.setColor(HSSFColor.BLUE.index);
			linkStyle.setFont(cellFont);
			likeCell.setCellStyle(linkStyle);
			
			// 创建一个居中格式
			HSSFCellStyle style = wb.createCellStyle();
			style.setAlignment(HSSFCellStyle.ALIGN_CENTER);
			
			/* 建立第每个子sheet对象 */
			HSSFSheet sheetDetail = wb.createSheet(sheetName); // 建立新的sheet对象
			if(title == null) {
				continue;
			}else {
				creatSheet(sheetDetail, style, title, cotent);
				index++;
			}
		}
		return wb;
	}
	
	/**
	 * 填充每个sheet中的内容、样式、标题
	 * @param sheet
	 * @param style
	 * @param title 
	 * @param values
	 */
	public static void creatSheet(HSSFSheet sheet, HSSFCellStyle style, String[] title, String[][] values) {
        // 第三步，在sheet中添加表头第0行,注意老版本poi对Excel的行数列数有限制
        HSSFRow row = sheet.createRow(0);

        //声明列对象
        HSSFCell cell = null;
        //存储最大列宽  
        Map<Integer,Integer> maxWidth = new HashMap<Integer,Integer>(); 

        //创建标题
        for (int i = 0; i < title.length; i++) {
            cell = row.createCell(i);
            cell.setCellValue(title[i]);
            cell.setCellStyle(style);
            
            maxWidth.put(i,title[i].length());
        }
        
        //创建内容
        if(values != null) {
        	for (int i = 0; i < values.length; i++) {
        		row = sheet.createRow(i + 1);
        		for (int j = 0; j < values[i].length; j++) {
        			//将内容按顺序赋给对应的列对象
        			HSSFCell createCell = row.createCell(j);
        			createCell.setCellValue(values[i][j]);
        			System.out.println(values[i][j]);
        			int length = createCell.getStringCellValue().getBytes().length  * 256 + 200;  
        			//这里把宽度最大限制到15000  
        			if (length>15000){  
        				length = 15000;  
        			}  
        			maxWidth.put(j,Math.max(length,maxWidth.get(j)));          
        		}
        	}
        }
        
        // 列宽自适应  
        for (int i = 0; i < title.length; i++) {  
            sheet.setColumnWidth(i,maxWidth.get(i));  
        }  
	}
	
	
	
	/**
	 * demo
	 * @param args
	 * @throws IOException
	 */
	public static void main1(String[] args) throws IOException {
		/* ！使用POI版本：3.10-FINAL */

		/* 建立新HSSFWorkbook对象 */
		HSSFWorkbook wb = new HSSFWorkbook();

		/* 建立新的sheet对象 */
		HSSFSheet sheet = wb.createSheet("汇总页面");
		HSSFRow row = sheet.createRow(0);

		/* 连接跳转 */
		HSSFCell likeCell = row.createCell(0);
		Hyperlink hyperlink = new HSSFHyperlink(Hyperlink.LINK_DOCUMENT);
		// "#"表示本文档 "明细页面"表示sheet页名称 "A10"表示第几列第几行
		hyperlink.setAddress("#明细页面!A10");
		likeCell.setHyperlink(hyperlink);
		// 点击进行跳转
		likeCell.setCellValue("1");

		/* 设置为超链接的样式 */
		HSSFCellStyle linkStyle = wb.createCellStyle();
		HSSFFont cellFont = wb.createFont();
		cellFont.setUnderline((byte) 1);
		cellFont.setColor(HSSFColor.BLUE.index);
		linkStyle.setFont(cellFont);
		likeCell.setCellStyle(linkStyle);

		/* 建立第二个sheet对象 */
		HSSFSheet sheet2 = wb.createSheet("明细页面"); // 建立新的sheet对象

		for (int i = 0; i < 30; i++) {
			HSSFRow row2 = sheet2.createRow(i);
			HSSFCell cell2 = row2.createCell( 0);
			cell2.setCellValue("测试第" + (i + 1) + "行");
		}

		/* 输出文件 */
		FileOutputStream fileOut = new FileOutputStream("e:\\汇总和明细.xls");
		wb.write(fileOut);
		fileOut.close();
	}

	public static void main(String[] args) {
		String s = "^-100|(0|[1-9][\\d]{0,3})(\\.[\\d]{1,1})?$";
		boolean matches = "0".matches(s);
		System.out.println(matches);
	}
	
}
